"""
MultiCall Smart Contract API
https://github.com/mds1/multicall
"""
import logging
from dataclasses import dataclass
from typing import Any, Callable, List, Optional, Sequence, Tuple

import eth_abi
from eth_abi.exceptions import DecodingError
from eth_account.signers.local import LocalAccount
from eth_typing import BlockIdentifier, BlockNumber, ChecksumAddress, HexAddress, HexStr
from hexbytes import HexBytes
from web3 import Web3
from web3._utils.abi import map_abi_data
from web3._utils.normalizers import BASE_RETURN_NORMALIZERS
from web3.contract.contract import Contract, ContractFunction
from web3.exceptions import ContractLogicError

from . import EthereumClient, EthereumNetwork, EthereumNetworkNotSupported
from .contracts import ContractBase, get_multicall_v3_contract
from .ethereum_client import EthereumTxSent
from .exceptions import BatchCallFunctionFailed, ContractAlreadyDeployed
from .utils import get_empty_tx_params

logger = logging.getLogger(__name__)


@dataclass
class MulticallResult:
    success: bool
    return_data: Optional[bytes]


@dataclass
class MulticallDecodedResult:
    success: bool
    return_data_decoded: Optional[Any]


class Multicall(ContractBase):
    # https://github.com/mds1/multicall#deployments
    ADDRESSES = {
        EthereumNetwork.MAINNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.GOERLI: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.SEPOLIA: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.OPTIMISM: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.OPTIMISM_GOERLI_TESTNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.ARBITRUM_ONE: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.ARBITRUM_NOVA: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.ARBITRUM_GOERLI: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.POLYGON: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.MUMBAI: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.POLYGON_ZKEVM: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.POLYGON_ZKEVM_TESTNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.GNOSIS: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.AVALANCHE_C_CHAIN: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.AVALANCHE_FUJI_TESTNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.FANTOM_TESTNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.FANTOM_OPERA: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.BNB_SMART_CHAIN_MAINNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.BNB_SMART_CHAIN_TESTNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.RINKEBY: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.KCC_MAINNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.KCC_TESTNET: "0x665683D9bd41C09cF38c3956c926D9924F1ADa97",
        EthereumNetwork.ROPSTEN: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.CELO_MAINNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.CELO_ALFAJORES_TESTNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.AURORA_MAINNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.BASE_GOERLI_TESTNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.METIS_ANDROMEDA_MAINNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.DOGECHAIN_MAINNET: "0x68a8609a60a008EFA633dfdec592c03B030cC508",
        EthereumNetwork.ZKSYNC_MAINNET: "0xF9cda624FBC7e059355ce98a31693d299FACd963",
        EthereumNetwork.IMMUTABLE_ZKEVM_TESTNET: "0x2CC787Ed364600B0222361C4188308Fa8E68bA60",
        EthereumNetwork.PLINGA_MAINNET: "0x0989576160f2e7092908BB9479631b901060b6e4",
        EthereumNetwork.ABSTRACT_TESTNET: "0xF9cda624FBC7e059355ce98a31693d299FACd963",
        EthereumNetwork.MEVERSE_CHAIN_TESTNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.DFK_CHAIN: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.CRONOS_TESTNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.GNOSIS_CHIADO_TESTNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.AMOY: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.SEI_NETWORK: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.HARMONY_MAINNET_SHARD_0: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.BASE: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.BLAST_SEPOLIA_TESTNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.PGN_PUBLIC_GOODS_NETWORK: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.EDGEWARE_EDGEEVM_MAINNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.THAICHAIN: "0x0DaD6130e832c21719C5CE3bae93454E16A84826",
        EthereumNetwork.FUSE_MAINNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.OKXCHAIN_MAINNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.PULSECHAIN: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.PULSECHAIN_TESTNET_V4: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.IMMUTABLE_ZKEVM: "0x236bdA4589e44e6850f5aC6a74BfCa398a86c6c0",
        EthereumNetwork.IOTEX_NETWORK_TESTNET: "0xb5cecD6894c6f473Ec726A176f1512399A2e355d",
        EthereumNetwork.PALM_TESTNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.UNREAL: "0x8b6B0e60D8CD84898Ea8b981065A12F876eA5677",
        EthereumNetwork.ASSET_CHAIN_TESTNET: "0x989F832D35988cb5e3eB001Fa2Fe789469EC31Ea",
        EthereumNetwork.KAIA_KAIROS_TESTNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.CANTO: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.LISK: "0xA9d71E1dd7ca26F26e656E66d6AA81ed7f745bf0",
        EthereumNetwork.PHOENIX_MAINNET: "0x498cF757a575cFF2c2Ed9f532f56Efa797f86442",
        EthereumNetwork.SCROLL_SEPOLIA_TESTNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.NEXI_MAINNET: "0x0277A46Cc69A57eE3A6C8c158bA874832F718B8E",
        EthereumNetwork.BEAM: "0x4956F15eFdc3dC16645e90Cc356eAFA65fFC65Ec",
        EthereumNetwork.TAIKO_MAINNET: "0xcb2436774C3e191c85056d248EF4260ce5f27A9D",
        EthereumNetwork.MINATO: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.EOS_EVM_NETWORK_TESTNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.KAVA_TESTNET: "0xDf1D724A7166261eEB015418fe8c7679BBEa7fd6",
        EthereumNetwork.IOTEX_NETWORK_MAINNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.FILECOIN_MAINNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.LINEA: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.CONFLUX_ESPACE_TESTNET: "0xEFf0078910f638cd81996cc117bccD3eDf2B072F",
        EthereumNetwork.BITTORRENT_CHAIN_MAINNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.WANCHAIN_TESTNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.THE_ROOT_NETWORK_MAINNET: "0xc9C2E2429AeC354916c476B30d729deDdC94988d",
        EthereumNetwork.RSS3_VSL_SEPOLIA_TESTNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.BOB: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.PREVIEWNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.BLAST: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.FORMA: "0xd53C6FFB123F7349A32980F87faeD8FfDc9ef079",
        EthereumNetwork.XDC_NETWORK: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.METAL_L2: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.BOB_SEPOLIA: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.X_LAYER_MAINNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.ZKFAIR_MAINNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.OASIS_SAPPHIRE: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.LINEA_GOERLI: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.MANTA_PACIFIC_MAINNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.XAI_MAINNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.NEON_EVM_MAINNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.ASTAR: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.WANCHAIN: "0xcDF6A1566e78EB4594c86Fe73Fcdc82429e97fbB",
        EthereumNetwork.FRAXTAL_TESTNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.X_LAYER_TESTNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.FUNKI_SEPOLIA_TESTNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.BERACHAIN_BARTIO: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.BASE_SEPOLIA_TESTNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.CRONOS_MAINNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.GARNET_HOLESKY: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.PUPPYNET: "0xA4029b74FBA366c926eDFA7Dd10B21C621170a4c",
        EthereumNetwork.ROLLUX_MAINNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.ZIRCUIT_TESTNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.ZKSYNC_SEPOLIA_TESTNET: "0xF9cda624FBC7e059355ce98a31693d299FACd963",
        EthereumNetwork.ATLETA_OLYMPIA: "0x1472ec6392180fb84F345d2455bCC75B26577115",
        EthereumNetwork.KAIA_MAINNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.SHIBARIUM: "0x864Bf681ADD6052395188A89101A1B37d3B4C961",
        EthereumNetwork.ASTAR_ZKEVM: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.INEVM_MAINNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.GRAVITY_ALPHA_MAINNET: "0xf8ac4BEB2F75d2cFFb588c63251347fdD629B92c",
        EthereumNetwork.SYSCOIN_MAINNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.JIBCHAIN_L1: "0xc0C8C486D1466C57Efe13C2bf000d4c56F47CBdC",
        EthereumNetwork.MODE: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.ROOTSTOCK_MAINNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.METACHAIN_MAINNET: "0x0000000000000000000000000000000000003001",
        EthereumNetwork.CYBER_MAINNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.MEVERSE_CHAIN_MAINNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.DEFICHAIN_EVM_NETWORK_MAINNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.POLYGON_ZKEVM_CARDONA_TESTNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.ROLLUX_TESTNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.SHAPE_SEPOLIA_TESTNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.MANTA_PACIFIC_TESTNET: "0x211B1643b95Fe76f11eD8880EE810ABD9A4cf56C",
        EthereumNetwork.RE_AL: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.TELOS_EVM_MAINNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.SEPOLIA_PGN_PUBLIC_GOODS_NETWORK: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.LISK_SEPOLIA_TESTNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.OPBNB_TESTNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.ZORA: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.MANTLE_SEPOLIA_TESTNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.CYBER_TESTNET: "0xffc391F0018269d4758AEA1a144772E8FB99545E",
        EthereumNetwork.KAVA: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.ZORA_SEPOLIA_TESTNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.OP_SEPOLIA_TESTNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.MOONBASE_ALPHA: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.LUKSO_TESTNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.SCROLL: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.OPBNB_MAINNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.FRAXTAL: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.CROSSBELL: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.REDSTONE: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.LUKSO_MAINNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.TAIKO_JOLNIR_L2: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.DARWINIA_NETWORK: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.SOPHON_TESTNET: "0x83c04d112adedA2C6D9037bb6ecb42E7f0b108Af",
        EthereumNetwork.XDC_APOTHEM_NETWORK: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.MOONBEAM: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.RSS3_VSL_MAINNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.METIS_GOERLI_TESTNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.SYSCOIN_TANENBAUM_TESTNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.LYRA_CHAIN: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.METACHAIN_ISTANBUL: "0x0000000000000000000000000000000000003001",
        EthereumNetwork.PLAYFI_ALBIREO_TESTNET: "0xF9cda624FBC7e059355ce98a31693d299FACd963",
        EthereumNetwork.NEON_EVM_DEVNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.CONFLUX_ESPACE: "0xEFf0078910f638cd81996cc117bccD3eDf2B072F",
        EthereumNetwork.BEAM_TESTNET: "0x9BF49b704EE2A095b95c1f2D4EB9010510c41C9E",
        EthereumNetwork.PUBLICMINT_MAINNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.MOONRIVER: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.MANTA_PACIFIC_SEPOLIA_TESTNET: "0xca54918f7B525C8df894668846506767412b53E3",
        EthereumNetwork.CRAB_NETWORK: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.PALM: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.MANTLE_TESTNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.ZETACHAIN_TESTNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.APEX_TESTNET: "0xf7642be33a6b18D16a995657adb5a68CD0438aE2",
        EthereumNetwork.ASTAR_ZKYOTO: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.MODE_TESTNET: "0xBAba8373113Fb7a68f195deF18732e01aF8eDfCF",
        EthereumNetwork.ARBITRUM_SEPOLIA: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.CORE_BLOCKCHAIN_MAINNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.MANTLE: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.HOLESKY: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.ETHERLINK_MAINNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.ZETACHAIN_MAINNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.DEFICHAIN_EVM_NETWORK_TESTNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.LINEA_SEPOLIA: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.BOBA_NETWORK: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.DARWINIA_KOI_TESTNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.THE_ROOT_NETWORK_PORCINI_TESTNET: "0xc9C2E2429AeC354916c476B30d729deDdC94988d",
        EthereumNetwork.ARTELA_TESTNET: "0xd07c8635f76e8745Ee7092fbb6e8fbc5FeF09DD7",
        EthereumNetwork.EOS_EVM_NETWORK: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.SKALE_NEBULA_HUB: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.SKALE_CALYPSO_HUB: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.SKALE_TITAN_HUB: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.SKALE_EUROPA_HUB_TESTNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.SKALE_EUROPA_HUB: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.SKALE_CALYPSO_HUB_TESTNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.SKALE_NEBULA_HUB_TESTNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.SKALE_TITAN_HUB_TESTNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.ZENCHAIN_TESTNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.SNAXCHAIN: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.SHAPE: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.FUSION_MAINNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.VICTION_TESTNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.ZIRCUIT_MAINNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.FUSION_TESTNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.AREON_NETWORK_MAINNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
        EthereumNetwork.FLARE_MAINNET: "0xcA11bde05977b3631167028862bE2a173976CA11",
    }

    def __init__(
        self,
        ethereum_client: EthereumClient,
        multicall_contract_address: Optional[ChecksumAddress] = None,
    ):
        ethereum_network = ethereum_client.get_network()
        address = multicall_contract_address or self.ADDRESSES.get(ethereum_network)
        mainnet_address = self.ADDRESSES.get(EthereumNetwork.MAINNET)
        if not address and mainnet_address:
            # Try with Multicall V3 deterministic address
            address = ChecksumAddress(HexAddress(HexStr(mainnet_address)))
            if not ethereum_client.is_contract(address):
                raise EthereumNetworkNotSupported(
                    "Multicall contract not available for %s", ethereum_network.name
                )

        if not address:
            raise ValueError("Contract address cannot be none")

        super().__init__(ChecksumAddress(HexAddress(HexStr(address))), ethereum_client)

    def get_contract_fn(self) -> Callable[[Web3, Optional[ChecksumAddress]], Contract]:
        return get_multicall_v3_contract

    @classmethod
    def deploy_contract(
        cls, ethereum_client: EthereumClient, deployer_account: LocalAccount
    ) -> Optional[EthereumTxSent]:
        """
        Deploy contract

        :param ethereum_client:
        :param deployer_account: Ethereum Account
        :return: ``EthereumTxSent`` with the deployed contract address, ``None`` if already deployed
        """
        contract_fn = cls.get_contract_fn(cls)  # type: ignore[arg-type]
        contract = contract_fn(ethereum_client.w3, None)
        constructor_data = contract.constructor().build_transaction(
            get_empty_tx_params()
        )["data"]

        try:
            ethereum_tx_sent = ethereum_client.deploy_and_initialize_contract(
                deployer_account, constructor_data
            )
            assert ethereum_tx_sent.contract_address is not None
            contract_address = ethereum_tx_sent.contract_address
            logger.info(
                "Deployed Multicall V2 Contract %s by %s",
                contract_address,
                deployer_account.address,
            )
            # Add address to addresses dictionary
            cls.ADDRESSES[ethereum_client.get_network()] = contract_address
            return ethereum_tx_sent
        except ContractAlreadyDeployed as e:
            cls.ADDRESSES[ethereum_client.get_network()] = e.address
            return None

    @staticmethod
    def _build_payload(
        contract_functions: Sequence[ContractFunction],
    ) -> Tuple[List[Tuple[ChecksumAddress, HexBytes]], List[List[Any]]]:
        targets_with_data = []
        output_types = []
        for contract_function in contract_functions:
            targets_with_data.append(
                (
                    contract_function.address,
                    HexBytes(contract_function._encode_transaction_data()),
                )
            )
            output_types.append(
                [output["type"] for output in contract_function.abi["outputs"]]
            )

        return targets_with_data, output_types

    def _build_payload_same_function(
        self,
        contract_function: ContractFunction,
        contract_addresses: Sequence[ChecksumAddress],
    ) -> Tuple[List[Tuple[ChecksumAddress, HexBytes]], List[List[Any]]]:
        targets_with_data = []
        output_types = []
        tx_data = HexBytes(contract_function._encode_transaction_data())
        for contract_address in contract_addresses:
            targets_with_data.append((contract_address, tx_data))
            output_types.append(
                [output["type"] for output in contract_function.abi["outputs"]]
            )

        return targets_with_data, output_types

    def _decode_data(self, output_type: Sequence[str], data: bytes) -> Optional[Any]:
        """

        :param output_type:
        :param data:
        :return:
        :raises: DecodingError
        """
        if data:
            try:
                decoded_values = eth_abi.decode(output_type, data)
                normalized_data = map_abi_data(
                    BASE_RETURN_NORMALIZERS, output_type, decoded_values
                )
                if len(normalized_data) == 1:
                    return normalized_data[0]
                else:
                    return normalized_data
            except DecodingError:
                logger.warning(
                    "Cannot decode %s using output-type %s", data, output_type
                )
                return data
        return None

    def _aggregate(
        self,
        targets_with_data: Sequence[Tuple[ChecksumAddress, bytes]],
        block_identifier: Optional[BlockIdentifier] = "latest",
    ) -> Tuple[BlockNumber, List[Optional[Any]]]:
        """

        :param targets_with_data: List of target `addresses` and `data` to be called in each Contract
        :param block_identifier:
        :return:
        :raises: BatchCallFunctionFailed
        """
        aggregate_parameter = [
            {"target": target, "callData": data} for target, data in targets_with_data
        ]
        try:
            return self.contract.functions.aggregate(aggregate_parameter).call(
                block_identifier=block_identifier or "latest"
            )
        except (ContractLogicError, OverflowError):
            raise BatchCallFunctionFailed

    def aggregate(
        self,
        contract_functions: Sequence[ContractFunction],
        block_identifier: Optional[BlockIdentifier] = "latest",
    ) -> Tuple[BlockNumber, List[Optional[Any]]]:
        """
        Calls ``aggregate`` on MakerDAO's Multicall contract. If a function called raises an error execution is stopped

        :param contract_functions:
        :param block_identifier:
        :return: A tuple with the ``blockNumber`` and a list with the decoded return values
        :raises: BatchCallFunctionFailed
        """
        targets_with_data, output_types = self._build_payload(contract_functions)
        block_number, results = self._aggregate(
            targets_with_data, block_identifier=block_identifier
        )
        decoded_results = [
            self._decode_data(output_type, data) if data is not None else None
            for output_type, data in zip(output_types, results)
        ]
        return block_number, decoded_results

    def _try_aggregate(
        self,
        targets_with_data: Sequence[Tuple[ChecksumAddress, bytes]],
        require_success: bool = False,
        block_identifier: Optional[BlockIdentifier] = "latest",
    ) -> List[MulticallResult]:
        """
        Calls ``try_aggregate`` on MakerDAO's Multicall contract.

        :param targets_with_data:
        :param require_success: If ``True``, an exception in any of the functions will stop the execution. Also, an
            invalid decoded value will stop the execution
        :param block_identifier:
        :return: A list with the decoded return values
        """

        aggregate_parameter = [
            {"target": target, "callData": data} for target, data in targets_with_data
        ]
        try:
            result = self.contract.functions.tryAggregate(
                require_success, aggregate_parameter
            ).call(block_identifier=block_identifier or "latest")

            if require_success and b"" in (data for _, data in result):
                # `b''` values are decoding errors/missing contracts/missing functions
                raise BatchCallFunctionFailed

            return [
                MulticallResult(success, data if data else None)
                for success, data in result
            ]
        except (ContractLogicError, OverflowError, ValueError):
            raise BatchCallFunctionFailed

    def try_aggregate(
        self,
        contract_functions: Sequence[ContractFunction],
        require_success: bool = False,
        block_identifier: Optional[BlockIdentifier] = "latest",
    ) -> List[MulticallDecodedResult]:
        """
        Calls ``try_aggregate`` on MakerDAO's Multicall contract.

        :param contract_functions:
        :param require_success: If ``True``, an exception in any of the functions will stop the execution
        :param block_identifier:
        :return: A list with the decoded return values
        """
        targets_with_data, output_types = self._build_payload(contract_functions)
        results = self._try_aggregate(
            targets_with_data,
            require_success=require_success,
            block_identifier=block_identifier,
        )
        return [
            MulticallDecodedResult(
                multicall_result.success,
                self._decode_data(output_type, multicall_result.return_data)
                if multicall_result.success and multicall_result.return_data is not None
                else multicall_result.return_data,
            )
            for output_type, multicall_result in zip(output_types, results)
        ]

    def try_aggregate_same_function(
        self,
        contract_function: ContractFunction,
        contract_addresses: Sequence[ChecksumAddress],
        require_success: bool = False,
        block_identifier: Optional[BlockIdentifier] = "latest",
    ) -> List[MulticallDecodedResult]:
        """
        Calls ``try_aggregate`` on MakerDAO's Multicall contract. Reuse same function with multiple contract addresses.
        It's more optimal due to instantiating ``ContractFunction`` objects is very demanding

        :param contract_function:
        :param contract_addresses:
        :param require_success: If ``True``, an exception in any of the functions will stop the execution
        :param block_identifier:
        :return: A list with the decoded return values
        """

        targets_with_data, output_types = self._build_payload_same_function(
            contract_function, contract_addresses
        )
        results = self._try_aggregate(
            targets_with_data,
            require_success=require_success,
            block_identifier=block_identifier,
        )
        return [
            MulticallDecodedResult(
                multicall_result.success,
                self._decode_data(output_type, multicall_result.return_data)
                if multicall_result.success and multicall_result.return_data is not None
                else multicall_result.return_data,
            )
            for output_type, multicall_result in zip(output_types, results)
        ]



from dataclasses import dataclass
from typing import Any, Dict, List, Optional


@dataclass
class ContractMetadata:
    name: Optional[str]
    abi: List[Dict[str, Any]]
    partial_match: bool
    implementation: Optional[str] = None



from enum import Enum, unique


class EthereumNetworkNotSupported(Exception):
    pass


@unique
class EthereumNetwork(Enum):
    """
    Use https://chainlist.org/ as a reference
    """

    UNKNOWN = -1
    OLYMPIC = 0
    MAINNET = 1
    EXPANSE_NETWORK = 2
    ROPSTEN = 3
    RINKEBY = 4
    GOERLI = 5
    KOTTI_TESTNET = 6
    THAICHAIN = 7
    UBIQ = 8
    UBIQ_NETWORK_TESTNET = 9
    OPTIMISM = 10
    METADIUM_MAINNET = 11
    METADIUM_TESTNET = 12
    DIODE_TESTNET_STAGING = 13
    FLARE_MAINNET = 14
    DIODE_PRENET = 15
    SONGBIRD_TESTNET_COSTON = 16
    THAICHAIN_2_0_THAIFI = 17
    THUNDERCORE_TESTNET = 18
    SONGBIRD_CANARY_NETWORK = 19
    ELASTOS_SMART_CHAIN = 20
    ELASTOS_SMART_CHAIN_TESTNET = 21
    ELA_DID_SIDECHAIN_MAINNET = 22
    ELA_DID_SIDECHAIN_TESTNET = 23
    KARDIACHAIN_MAINNET = 24
    CRONOS_MAINNET = 25
    GENESIS_L1_TESTNET = 26
    SHIBACHAIN = 27
    BOBA_NETWORK_RINKEBY_TESTNET = 28
    GENESIS_L1 = 29
    ROOTSTOCK_MAINNET = 30
    ROOTSTOCK_TESTNET = 31
    GOODDATA_TESTNET = 32
    GOODDATA_MAINNET = 33
    SECURECHAIN_MAINNET = 34
    TBWG_CHAIN = 35
    DXCHAIN_MAINNET = 36
    XPLA_MAINNET = 37
    VALORBIT = 38
    U2U_SOLARIS_MAINNET = 39
    TELOS_EVM_MAINNET = 40
    TELOS_EVM_TESTNET = 41
    LUKSO_MAINNET = 42
    DARWINIA_PANGOLIN_TESTNET = 43
    CRAB_NETWORK = 44
    DARWINIA_PANGORO_TESTNET = 45
    DARWINIA_NETWORK = 46
    ACRIA_INTELLICHAIN = 47
    ENNOTHEM_MAINNET_PROTEROZOIC = 48
    ENNOTHEM_TESTNET_PIONEER = 49
    XDC_NETWORK = 50
    XDC_APOTHEM_NETWORK = 51
    COINEX_SMART_CHAIN_MAINNET = 52
    COINEX_SMART_CHAIN_TESTNET = 53
    OPENPIECE_MAINNET = 54
    ZYX_MAINNET = 55
    BNB_SMART_CHAIN_MAINNET = 56
    SYSCOIN_MAINNET = 57
    ONTOLOGY_MAINNET = 58
    EOS_EVM_LEGACY = 59
    GOCHAIN = 60
    ETHEREUM_CLASSIC = 61
    MORDEN_TESTNET = 62
    MORDOR_TESTNET = 63
    ELLAISM = 64
    OKEXCHAIN_TESTNET = 65
    OKXCHAIN_MAINNET = 66
    DBCHAIN_TESTNET = 67
    SOTERONE_MAINNET = 68
    OPTIMISM_KOVAN = 69
    HOO_SMART_CHAIN = 70
    CONFLUX_ESPACE_TESTNET = 71
    DXCHAIN_TESTNET = 72
    FNCY = 73
    IDCHAIN_MAINNET = 74
    DECIMAL_SMART_CHAIN_MAINNET = 75
    MIX = 76
    POA_NETWORK_SOKOL = 77
    PRIMUSCHAIN_MAINNET = 78
    ZENITH_MAINNET = 79
    GENECHAIN = 80
    JAPAN_OPEN_CHAIN_MAINNET = 81
    METER_MAINNET = 82
    METER_TESTNET = 83
    LINQTO_DEVNET = 84
    GATECHAIN_TESTNET = 85
    GATECHAIN_MAINNET = 86
    NOVA_NETWORK = 87
    VICTION = 88
    VICTION_TESTNET = 89
    GARIZON_STAGE0 = 90
    GARIZON_STAGE1 = 91
    GARIZON_STAGE2 = 92
    GARIZON_STAGE3 = 93
    SWISSDLT = 94
    CAMDL_MAINNET = 95
    BITKUB_CHAIN = 96
    BNB_SMART_CHAIN_TESTNET = 97
    SIX_PROTOCOL = 98
    POA_NETWORK_CORE = 99
    GNOSIS = 100
    ETHERINC = 101
    WEB3GAMES_TESTNET = 102
    WORLDLAND_MAINNET = 103
    KAIBA_LIGHTNING_CHAIN_TESTNET = 104
    WEB3GAMES_DEVNET = 105
    VELAS_EVM_MAINNET = 106
    NEBULA_TESTNET = 107
    THUNDERCORE_MAINNET = 108
    SHIBARIUM = 109
    PROTON_TESTNET = 110
    ETHERLITE_CHAIN = 111
    COINBIT_MAINNET = 112
    DEHVO = 113
    FLARE_TESTNET_COSTON2 = 114
    DEBANK_TESTNET_DEPRECATED = 115
    DEBANK_MAINNET = 116
    UPTICK_MAINNET = 117
    ARCOLOGY_TESTNET = 118
    ENULS_MAINNET = 119
    ENULS_TESTNET = 120
    REALCHAIN_MAINNET = 121
    FUSE_MAINNET = 122
    FUSE_SPARKNET = 123
    DECENTRALIZED_WEB_MAINNET = 124
    OYCHAIN_TESTNET = 125
    OYCHAIN_MAINNET = 126
    FACTORY_127_MAINNET = 127
    HUOBI_ECO_CHAIN_MAINNET = 128
    INNOVATOR_CHAIN = 129
    UNICHAIN = 130
    ENGRAM_TESTNET = 131
    NAMEFI_CHAIN_MAINNET = 132
    HASHKEY_CHAIN_TESTNET = 133
    IEXEC_SIDECHAIN = 134
    ALYX_CHAIN_TESTNET = 135
    DEAMCHAIN_MAINNET = 136
    POLYGON = 137
    DEFI_ORACLE_META_MAINNET = 138
    WOOPCHAIN_MAINNET = 139
    ETERNAL_MAINNET = 140
    OPENPIECE_TESTNET = 141
    DAX_CHAIN = 142
    MONAD_MAINNET = 143
    PHI_NETWORK_V2 = 144
    SORAAI_TESTNET = 145
    SONIC_MAINNET = 146
    FLAG_MAINNET = 147
    SHIMMEREVM = 148
    SIX_PROTOCOL_TESTNET = 150
    REDBELLY_NETWORK_MAINNET = 151
    REDBELLY_NETWORK_DEVNET = 152
    REDBELLY_NETWORK_TESTNET = 153
    REDBELLY_NETWORK_TGE = 154
    TENET_TESTNET = 155
    OEBLOCK_TESTNET = 156
    PUPPYNET = 157
    ROBURNA_MAINNET = 158
    ROBURNA_TESTNET = 159
    ARMONIA_EVA_CHAIN_MAINNET = 160
    ARMONIA_EVA_CHAIN_TESTNET = 161
    LIGHTSTREAMS_TESTNET = 162
    LIGHTSTREAMS_MAINNET = 163
    OMNI_OMEGA_TESTNET = 164
    OMNI_TESTNET_DEPRECATED = 165
    OMNI = 166
    ATOSHI_TESTNET = 167
    AIOZ_NETWORK = 168
    MANTA_PACIFIC_MAINNET = 169
    HOO_SMART_CHAIN_TESTNET = 170
    CO2E_LEDGER = 171
    LATAM_BLOCKCHAIN_RESIL_TESTNET = 172
    OTC = 175
    DC_MAINNET = 176
    HASHKEY_CHAIN = 177
    ABEY_TESTNET = 178
    ABEY_MAINNET = 179
    AME_CHAIN_MAINNET = 180
    WATERFALL_NETWORK = 181
    IOST_MAINNET = 182
    ETHERNITY = 183
    DOJIMA_TESTNET = 184
    MINT_MAINNET = 185
    SEELE_MAINNET = 186
    DOJIMA = 187
    BMC_MAINNET = 188
    BMC_TESTNET = 189
    CMDAO_BBQ_CHAIN = 190
    FILEFILEGO = 191
    CRYPTO_EMERGENCY = 193
    X_LAYER_TESTNET = 195
    X_LAYER_MAINNET = 196
    NEUTRINOS_TESTNET = 197
    BITCHAIN_MAINNET = 198
    BITTORRENT_CHAIN_MAINNET = 199
    ARBITRUM_ON_XDAI = 200
    MOAC_TESTNET = 201
    EDGELESS_TESTNET = 202
    OPBNB_MAINNET = 204
    EKAASH = 205
    VINUCHAIN_TESTNET = 206
    VINUCHAIN_NETWORK = 207
    STRUCTX_MAINNET = 208
    BITNET = 210
    FREIGHT_TRUST_NETWORK = 211
    MAPO_MAKALU = 212
    B2_HUB_MAINNET = 213
    SHINARIUM_MAINNET = 214
    SIRIUSNET_V2 = 217
    SOTERONE_MAINNET_OLD = 218
    SCALIND_TESTNET = 220
    BLOCKEX_MAINNET = 221
    PERMISSION = 222
    B2_MAINNET = 223
    VIRIDIS_TESTNET = 224
    LACHAIN_MAINNET = 225
    LACHAIN_TESTNET = 226
    PROM = 227
    MIND_NETWORK_MAINNET = 228
    SWAPDEX = 230
    ETHERNITY_TESTNET = 233
    PROTOJUMBO_TESTNET = 234
    DEAMCHAIN_TESTNET = 236
    BLAST_MAINNET = 238
    CRONOS_ZKEVM_TESTNET = 240
    PLINGA_MAINNET = 242
    ENERGY_WEB_CHAIN = 246
    OASYS_MAINNET = 248
    FANTOM_OPERA = 250
    GLIDE_L1_PROTOCOL_XP = 251
    FRAXTAL = 252
    GLIDE_L2_PROTOCOL_XP = 253
    SWAN_CHAIN_MAINNET = 254
    KROMA = 255
    HUOBI_ECO_CHAIN_TESTNET = 256
    SETHEUM = 258
    NEONLINK_MAINNET = 259
    GURU_NETWORK = 260
    GURU_NETWORK_TESTNET = 261
    SUR_BLOCKCHAIN_NETWORK = 262
    NEURA = 266
    NEURA_TESTNET = 267
    NEURA_DEVNET = 268
    HIGH_PERFORMANCE_BLOCKCHAIN = 269
    EGONCOIN_MAINNET = 271
    LACHAIN = 274
    XFAIR_AI_MAINNET = 278
    BPX_CHAIN = 279
    ZKSYNC_ERA_GOERLI_TESTNET_DEPRECATED = 280
    DEPRECATED_CRONOS_ZKEVM_TESTNET = 282
    BOBA_NETWORK = 288
    ORDERLY_MAINNET = 291
    DAVINCI = 293
    HEDERA_MAINNET = 295
    HEDERA_TESTNET = 296
    HEDERA_PREVIEWNET = 297
    HEDERA_LOCALNET = 298
    ZKSYNC_SEPOLIA_TESTNET = 300
    BOBAOPERA = 301
    ZKCANDY_SEPOLIA_TESTNET = 302
    NEUROCHAIN_TESTNET = 303
    ZKSATS_MAINNET = 305
    LOVELY_NETWORK_TESTNET = 307
    FURTHEON = 308
    WYZTH_TESTNET = 309
    OMAX_MAINNET = 311
    NEUROCHAIN_MAINNET = 313
    FILECOIN_MAINNET = 314
    KCC_MAINNET = 321
    KCC_TESTNET = 322
    COSVM_MAINNET = 323
    ZKSYNC_MAINNET = 324
    GRVT_EXCHANGE = 325
    GRVT_EXCHANGE_TESTNET = 326
    OMAX_TESTNET = 332
    WEB3Q_MAINNET = 333
    DFK_CHAIN_TEST = 335
    SHIDEN = 336
    CRONOS_TESTNET = 338
    TSC_MAINNET = 345
    SHAPE = 360
    THETA_MAINNET = 361
    THETA_SAPPHIRE_TESTNET = 363
    THETA_AMBER_TESTNET = 364
    THETA_TESTNET = 365
    PULSECHAIN = 369
    CONSTA_TESTNET = 371
    ZKAMOEBA_TESTNET = 380
    ZKAMOEBA_MAINNET = 381
    LISINSKI = 385
    CRONOS_ZKEVM_MAINNET = 388
    CAMDL_TESTNET = 395
    NEAR_PROTOCOL = 397
    NEAR_PROTOCOL_TESTNET = 398
    NATIV3_MAINNET = 399
    HYPERONCHAIN_TESTNET = 400
    OZONE_CHAIN_TESTNET = 401
    SYNDR_L3 = 404
    PEPE_CHAIN_MAINNET = 411
    SX_NETWORK_MAINNET = 416
    LATESTNET = 418
    OPTIMISM_GOERLI_TESTNET = 420
    VIRIDIS_MAINNET = 422
    PGN_PUBLIC_GOODS_NETWORK = 424
    STENIX_MAINNET = 425
    THE_WIDOWS_MITE = 426
    ZEETH_CHAIN = 427
    GESO_VERSE = 428
    BOYAA_MAINNET = 434
    TEN_TESTNET = 443
    SYNAPSE_CHAIN_TESTNET = 444
    ARZIO_CHAIN = 456
    AREON_NETWORK_TESTNET = 462
    AREON_NETWORK_MAINNET = 463
    APPCHAIN = 466
    FORM_NETWORK = 478
    WORLD_CHAIN = 480
    RUPAYA = 499
    CAMINO_C_CHAIN = 500
    COLUMBUS_TEST_NETWORK = 501
    SYNDICATE_CHAIN = 510
    DOUBLE_A_CHAIN_MAINNET = 512
    DOUBLE_A_CHAIN_TESTNET = 513
    GEAR_ZERO_NETWORK_MAINNET = 516
    XT_SMART_CHAIN_MAINNET = 520
    FIRECHAIN_MAINNET = 529
    F_XCORE_MAINNET_NETWORK = 530
    CANDLE = 534
    OPTRUST_MAINNET = 537
    PAWCHAIN_TESTNET = 542
    EVM_ON_FLOW_TESTNET = 545
    VELA1_CHAIN_MAINNET = 555
    TAO_NETWORK = 558
    PROMETHEUZ_TESTNET = 565
    DOGECHAIN_TESTNET = 568
    ROLLUX_MAINNET = 570
    METACHAIN_MAINNET = 571
    FILENOVA_MAINNET = 579
    METIS_STARDUST_TESTNET = 588
    ASTAR = 592
    ACALA_MANDALA_TESTNET_TC9 = 595
    KARURA_NETWORK_TESTNET = 596
    ACALA_NETWORK_TESTNET = 597
    METIS_GOERLI_TESTNET = 599
    MESHNYAN_TESTNET = 600
    VINE_TESTNET = 601
    DARWIN_DEVNET = 610
    EIOB_MAINNET = 612
    GRAPHLINQ_BLOCKCHAIN_MAINNET = 614
    BINARY_MAINNET = 624
    BINARY_SEPOLIA = 625
    AVOCADO = 634
    PREVIEWNET = 646
    SX_NETWORK_TESTNET = 647
    ENDURANCE_SMART_CHAIN_MAINNET = 648
    KALICHAIN_TESTNET = 653
    KALICHAIN = 654
    ULTRONSMARTCHAIN = 662
    PIXIE_CHAIN_TESTNET = 666
    LAOS_ARRAKIS = 667
    JUNCACHAIN = 668
    JUNCACHAIN_TESTNET = 669
    KARURA_NETWORK = 686
    NERO_TESTNET = 689
    REDSTONE = 690
    MATCHAIN = 698
    MATCHAIN_TESTNET = 699
    STAR_SOCIAL_TESTNET = 700
    DARWINIA_KOI_TESTNET = 701
    BLOCKCHAIN_STATION_MAINNET = 707
    BLOCKCHAIN_STATION_TESTNET = 708
    HIGHBURY = 710
    TUCANA = 711
    BIRDEE_2 = 712
    VRCSCAN_MAINNET = 713
    SHIBARIUM_BETA = 719
    LYCAN_CHAIN = 721
    BLUCRATES = 727
    LOVELY_NETWORK_MAINNET = 730
    CANTO_TESTNET = 740
    VENTION_SMART_CHAIN_TESTNET = 741
    SCRIPT_TESTNET = 742
    EVM_ON_FLOW = 747
    QL1 = 766
    OPENCHAIN_TESTNET = 776
    CHEAPETH = 777
    MAAL_CHAIN = 786
    ACALA_NETWORK = 787
    AEROCHAIN_TESTNET = 788
    PATEX = 789
    RUPAYA_TESTNET = 799
    LUCID_BLOCKCHAIN = 800
    HAIC = 803
    PORTAL_FANTASY_CHAIN_TEST = 808
    HAVEN1_TESTNET = 810
    QITMEER_NETWORK_MAINNET = 813
    FIRECHAIN_ZKEVM = 814
    BEONE_CHAIN_MAINNET = 818
    CALLISTO_MAINNET = 820
    CALLISTO_TESTNET_DEPRECATED = 821
    RUNIC_CHAIN_TESTNET = 822
    DAILY_NETWORK_MAINNET = 824
    DAILY_NETWORK_TESTNET = 825
    CHECKDOT_BLOCKCHAIN_DEVNET = 831
    TARAXA_MAINNET = 841
    TARAXA_TESTNET = 842
    HONGKONG_MAINNET = 852
    ZEETH_CHAIN_DEV = 859
    FANTASIA_CHAIN_MAINNET = 868
    BANDAI_NAMCO_RESEARCH_VERSE_MAINNET = 876
    DEXIT_NETWORK = 877
    AMBROS_CHAIN_MAINNET = 880
    WANCHAIN = 888
    MAXI_CHAIN_TESTNET = 898
    MAXI_CHAIN_MAINNET = 899
    GARIZON_TESTNET_STAGE0 = 900
    GARIZON_TESTNET_STAGE1 = 901
    GARIZON_TESTNET_STAGE2 = 902
    GARIZON_TESTNET_STAGE3 = 903
    PORTAL_FANTASY_CHAIN = 909
    DECENTRABONE_LAYER1_TESTNET = 910
    TAPROOT_MAINNET = 911
    RINIA_TESTNET = 917
    SLERFCHAIN_MAINNET = 918
    MODE_TESTNET = 919
    YIDARK_CHAIN_MAINNET = 927
    HAUST_MAINNET = 938
    PULSECHAIN_TESTNET = 940
    PULSECHAIN_TESTNET_V2B = 941
    PULSECHAIN_TESTNET_V3 = 942
    PULSECHAIN_TESTNET_V4 = 943
    SUBTENSOR_EVM_TESTNET = 945
    MUNODE_TESTNET = 956
    LYRA_CHAIN = 957
    BTC20_SMART_CHAIN = 963
    ETHXY = 969
    OORT_MAINNET = 970
    OORT_HUYGENS = 971
    OORT_ASCRAEUS = 972
    PALM_SMART_CHAIN = 973
    NEPAL_BLOCKCHAIN_NETWORK = 977
    ETHXY_TESTNET = 979
    TOP_MAINNET_EVM = 980
    MEMO_SMART_CHAIN_MAINNET = 985
    BINARYCHAIN_MAINNET = 987
    TOP_MAINNET = 989
    ELIBERTY_MAINNET = 990
    _5IRECHAIN_MAINNET = 995
    BIFROST_POLKADOT_MAINNET = 996
    _5IRECHAIN_THUNDER_TESTNET = 997
    LUCKY_NETWORK = 998
    WANCHAIN_TESTNET = 999
    GTON_MAINNET = 1000
    KAIA_KAIROS_TESTNET = 1001
    TECTUM_EMISSION_TOKEN = 1003
    T_EKTA = 1004
    LEMONCHAINTESTNET = 1005
    LEMONCHAIN = 1006
    NEWTON_TESTNET = 1007
    EURUS_MAINNET = 1008
    JUMBOCHAIN_MAINNET = 1009
    EVRICE_NETWORK = 1010
    REBUS_MAINNET = 1011
    NEWTON = 1012
    SAKURA = 1022
    CLOVER_TESTNET = 1023
    CLV_PARACHAIN = 1024
    BITTORRENT_CHAIN_TESTNET = 1028
    BITTORRENT_CHAIN_DONAU = 1029
    CONFLUX_ESPACE = 1030
    PROXY_NETWORK_TESTNET = 1031
    BRONOS_TESTNET = 1038
    BRONOS_MAINNET = 1039
    SHIMMEREVM_TESTNET_DEPRECATED = 1071
    SHIMMEREVM_TESTNET_DEPRECATED_1072 = 1072
    SHIMMEREVM_TESTNET = 1073
    IOTA_EVM_TESTNET = 1075
    MINTARA_TESTNET = 1079
    MINTARA_MAINNET = 1080
    METIS_ANDROMEDA_MAINNET = 1088
    HUMANS_AI_MAINNET = 1089
    MOAC_MAINNET = 1099
    DYMENSION = 1100
    POLYGON_ZKEVM = 1101
    BLXQ_TESTNET = 1107
    BLXQ_MAINNET = 1108
    WEMIX3_0_MAINNET = 1111
    WEMIX3_0_TESTNET = 1112
    B2_HUB_TESTNET = 1113
    CORE_BLOCKCHAIN_TESTNET2 = 1114
    CORE_BLOCKCHAIN_TESTNET = 1115
    CORE_BLOCKCHAIN_MAINNET = 1116
    DOGCOIN_MAINNET = 1117
    B2_TESTNET = 1123
    DEFICHAIN_EVM_NETWORK_MAINNET = 1130
    DEFICHAIN_EVM_NETWORK_TESTNET = 1131
    DEFIMETACHAIN_CHANGI_TESTNET = 1133
    LISK = 1135
    AMSTAR_TESTNET = 1138
    MATHCHAIN = 1139
    MATHCHAIN_TESTNET = 1140
    FLAG_TESTNET = 1147
    SYMPLEXIA_SMART_CHAIN = 1149
    ORIGIN_TESTNET = 1170
    LITHEUM_TEST_NETWORK = 1174
    SMART_HOST_TEKNOLOJI_TESTNET = 1177
    CLUBMOS_MAINNET = 1188
    IORA_CHAIN = 1197
    CUCKOO_CHAIN = 1200
    EVANESCO_TESTNET = 1201
    WORLD_TRADE_TECHNICAL_CHAIN_MAINNET = 1202
    SAITABLOCKCHAIN_SBC = 1209
    CUCKOO_SEPOLIA = 1210
    ADF_CHAIN_TESTNET = 1212
    POPCATEUM_MAINNET = 1213
    ENTERCHAIN_MAINNET = 1214
    ADF_CHAIN = 1215
    CYCLE_NETWORK_TESTNET = 1221
    CYCLE_NETWORK_TESTNET_JELLYFISH = 1223
    HYBRID_TESTNET_DEPRECATED = 1224
    HYBRID_TESTNET = 1225
    BITCOIN_PROTOCOL_TESTNET = 1227
    CYCLE_NETWORK_TESTNET_CUTTLEFISH = 1228
    EXZO_NETWORK_MAINNET = 1229
    ULTRON_TESTNET = 1230
    ULTRON_MAINNET = 1231
    STEP_NETWORK = 1234
    ITX_MAINNET = 1235
    ARC_MAINNET = 1243
    ARC_TESTNET = 1244
    OM_PLATFORM_MAINNET = 1246
    DOGETHER_MAINNET = 1248
    CIC_CHAIN_TESTNET = 1252
    METACCES_TESTNET = 1260
    HALO_MAINNET = 1280
    MOONBEAM = 1284
    MOONRIVER = 1285
    MOONROCK_OLD = 1286
    MOONBASE_ALPHA = 1287
    MOONROCK = 1288
    SWISSTRONIK_TESTNET = 1291
    BOBABEAM = 1294
    BOBABASE_TESTNET = 1297
    ARGOCHAIN_TESTNET = 1298
    ARGOCHAIN = 1299
    UNICHAIN_SEPOLIA_TESTNET = 1301
    DOS_FUJI_SUBNET = 1311
    JAIHO_CHAIN = 1313
    ALYX_MAINNET = 1314
    AIA_MAINNET = 1319
    AIA_TESTNET = 1320
    SEI_TESTNET = 1328
    SEI_NETWORK = 1329
    GANACHE = 1337
    ELYSIUM_TESTNET = 1338
    ELYSIUM_MAINNET = 1339
    BLITZ_SUBNET = 1343
    CIC_CHAIN_MAINNET = 1353
    ZAFIRIUM_MAINNET = 1369
    RAMESTTA_MAINNET = 1370
    PINGAKSHA_TESTNET = 1377
    KALAR_CHAIN = 1379
    AMSTAR_MAINNET = 1388
    JOSEON_MAINNET = 1392
    POLYGON_ZKEVM_TESTNET_OLD = 1402
    SILICON_ZKEVM_SEPOLIA_TESTNET_DEPRECATED = 1414
    POLYGON_ZKEVM_TESTNET_PRE_AUDIT_UPGRADED = 1422
    RIKEZA_NETWORK_MAINNET = 1433
    LIVING_ASSETS_MAINNET = 1440
    POLYGON_ZKEVM_TESTNET = 1442
    GIL_TESTNET = 1452
    METACHAIN_ISTANBUL = 1453
    CTEX_SCAN_BLOCKCHAIN = 1455
    ZKBASE_MAINNET = 1456
    VANA = 1480
    VITRUVEO_MAINNET = 1490
    IDOS_GAMES_CHAIN_TESTNET = 1499
    BEVM_CANARY = 1501
    SHERPAX_MAINNET = 1506
    SHERPAX_TESTNET = 1507
    STORY_TESTNET = 1513
    BEAGLE_MESSAGING_CHAIN = 1515
    STORY_ODYSSEY_TESTNET = 1516
    DATACORE_SMART_CHAIN = 1555
    TENET = 1559
    STARCHAIN_TESTNET = 1570
    STARCHAIN = 1578
    BETHERANCE = 1605
    ETHEREUM_INSCRIPTION_MAINNET = 1617
    CATECOIN_CHAIN_MAINNET = 1618
    ATHEIOS = 1620
    GRAVITY_ALPHA_MAINNET = 1625
    PIVOTAL_MAINNET = 1648
    BTACHAIN = 1657
    LIQUICHAIN = 1662
    HORIZEN_GOBI_TESTNET = 1663
    MINT_TESTNET = 1686
    MINT_SEPOLIA_TESTNET = 1687
    LUDAN_MAINNET = 1688
    NERO_MAINNET = 1689
    ANYTYPE_EVM_CHAIN = 1701
    TBSI_MAINNET = 1707
    TBSI_TESTNET = 1708
    DORIC_NETWORK = 1717
    PALETTE_CHAIN_MAINNET = 1718
    REYA_NETWORK = 1729
    METAL_L2_TESTNET = 1740
    METAL_L2 = 1750
    PARTYCHAIN = 1773
    GAUSS_MAINNET = 1777
    ZKBASE_SEPOLIA_TESTNET = 1789
    KERLEANO = 1804
    RABBIT_ANALOG_TESTNET_CHAIN = 1807
    LIF3_CHAIN_TESTNET = 1811
    CUBE_CHAIN_MAINNET = 1818
    CUBE_CHAIN_TESTNET = 1819
    RUBY_SMART_CHAIN_MAINNET = 1821
    PLAYBLOCK = 1829
    VERIFY_TESTNET = 1833
    HIGHOCTANE_SUBNET = 1853
    TESLAFUNDS = 1856
    SONEIUM = 1868
    WHITECHAIN = 1875
    GITSHOCK_CARTENZ_TESTNET = 1881
    LIGHTLINK_PHOENIX_MAINNET = 1890
    LIGHTLINK_PEGASUS_TESTNET = 1891
    BON_NETWORK = 1898
    REDEFI_LAYER_2 = 1899
    SPORTS_CHAIN_NETWORK = 1904
    BITCICHAIN_MAINNET = 1907
    BITCICHAIN_TESTNET = 1908
    MERKLE_SCAN = 1909
    SCALIND = 1911
    RUBY_SMART_CHAIN_TESTNET = 1912
    UPB_CRESCDI_TESTNET = 1918
    SWELLCHAIN = 1923
    SWELLCHAIN_TESTNET = 1924
    ARVIX_TESTNET = 1927
    ONUS_CHAIN_TESTNET = 1945
    MINATO = 1946
    BIONIX_TESTNET = 1949
    D_CHAIN_MAINNET = 1951
    SELENDRA_NETWORK_TESTNET = 1953
    DEXILLA_TESTNET = 1954
    AIW3_TESTNET = 1956
    SELENDRA_NETWORK_MAINNET = 1961
    ELEANOR = 1967
    SUPER_SMART_CHAIN_TESTNET = 1969
    SUPER_SMART_CHAIN_MAINNET = 1970
    ATELIER = 1971
    REDECOIN = 1972
    ONUS_CHAIN_MAINNET = 1975
    EURUS_TESTNET = 1984
    SATOSHIE = 1985
    SATOSHIE_TESTNET = 1986
    ETHERGEM = 1987
    HUBBLE_EXCHANGE = 1992
    B3_SEPOLIA_TESTNET = 1993
    EKTA = 1994
    EDEXA_TESTNET = 1995
    SANKO = 1996
    KYOTO = 1997
    KYOTO_TESTNET = 1998
    DOGECHAIN_MAINNET = 2000
    MILKOMEDA_C1_MAINNET = 2001
    MILKOMEDA_A1_MAINNET = 2002
    METALINK_NETWORK = 2004
    CLOUDWALK_TESTNET = 2008
    CLOUDWALK_MAINNET = 2009
    PANARCHY = 2013
    NOW_CHAIN_TESTNET = 2014
    MAINNETZ_MAINNET = 2016
    ADIRI = 2017
    PUBLICMINT_DEVNET = 2018
    PUBLICMINT_TESTNET = 2019
    PUBLICMINT_MAINNET = 2020
    EDGEWARE_EDGEEVM_MAINNET = 2021
    BERESHEET_BEREEVM_TESTNET = 2022
    TAYCAN_TESTNET = 2023
    SWAN_SATURN_TESTNET = 2024
    RANGERS_PROTOCOL_MAINNET = 2025
    EDGELESS_NETWORK = 2026
    CENTRIFUGE = 2031
    CATALYST = 2032
    PHALA_NETWORK = 2035
    KIWI_SUBNET = 2037
    SHRAPNEL_TESTNET = 2038
    ALEPH_ZERO = 2039
    VANAR_MAINNET = 2040
    NEUROWEB = 2043
    SHRAPNEL_SUBNET = 2044
    AIW3_MAINNET = 2045
    STRATOS_TESTNET = 2047
    STRATOS = 2048
    MOVO_SMART_CHAIN_MAINNET = 2049
    METACCES_MAINNET = 2071
    QUOKKACOIN_MAINNET = 2077
    ALTAIR = 2088
    ALGOL = 2089
    ECOBALL_MAINNET = 2100
    ECOBALL_TESTNET_ESPUMA = 2101
    EXOSAMA_NETWORK = 2109
    UCHAIN_MAINNET = 2112
    CATENA_MAINNET = 2121
    METAPLAYERONE_MAINNET = 2122
    METAPLAYERONE_DUBAI_TESTNET = 2124
    BIGSHORTBETS_TESTNET = 2136
    BIGSHORTBETS = 2137
    DEFI_ORACLE_META_TESTNET = 2138
    ONENESS_NETWORK = 2140
    ONENESS_TESTNET = 2141
    BOSAGORA_MAINNET = 2151
    FINDORA_MAINNET = 2152
    FINDORA_TESTNET = 2153
    FINDORA_FORGE = 2154
    ANIMECHAIN_TESTNET = 2162
    GAME7 = 2187
    SNAXCHAIN = 2192
    MOONSAMA_NETWORK = 2199
    ANTOFY_MAINNET = 2202
    BITCOIN_EVM = 2203
    EVANESCO_MAINNET = 2213
    KAVA_TESTNET = 2221
    KAVA = 2222
    VCHAIN_MAINNET = 2223
    KREST_NETWORK = 2241
    BOMB_CHAIN = 2300
    EBRO_NETWORK = 2306
    AREVIA = 2309
    CHRONICLE_VESUVIUS_LIT_PROTOCOL_TESTNET = 2311
    SOMA_NETWORK_TESTNET = 2323
    ALTCOINCHAIN = 2330
    RSS3_VSL_SEPOLIA_TESTNET = 2331
    SOMA_NETWORK_MAINNET = 2332
    ATLETA_OLYMPIA = 2340
    OMNIA_CHAIN = 2342
    SILICON_ZKEVM = 2355
    _DEPRECATED_KROMA_SEPOLIA = 2357
    KROMA_SEPOLIA = 2358
    NEXIS_NETWORK_TESTNET = 2370
    BOMB_CHAIN_TESTNET = 2399
    TCG_VERSE_MAINNET = 2400
    K2_MAINNET = 2410
    XODEX = 2415
    KING_OF_LEGENDS_MAINNET = 2425
    POLYGON_ZKEVM_CARDONA_TESTNET = 2442
    HYBRID_CHAIN_NETWORK_TESTNET = 2458
    HYBRID_CHAIN_NETWORK_MAINNET = 2468
    _6DEGREE_OF_OUTREACH = 2477
    UNICORN_ULTRA_NEBULAS_TESTNET = 2484
    NOW_CHAIN_MAINNET = 2488
    KARAK_GOERLI = 2511
    K2_TESTNET = 2512
    FRAXTAL_TESTNET = 2522
    INEVM_MAINNET = 2525
    BAHAMUT_HORIZON = 2552
    KORTHO_MAINNET = 2559
    TECHPAY_MAINNET = 2569
    POCRNET = 2606
    REDLIGHT_CHAIN_MAINNET = 2611
    EZCHAIN_C_CHAIN_MAINNET = 2612
    EZCHAIN_C_CHAIN_TESTNET = 2613
    WHITECHAIN_TESTNET = 2625
    AILAYER_TESTNET = 2648
    AILAYER_MAINNET = 2649
    APEX = 2662
    MORPH_TESTNET = 2710
    K_LAOS = 2718
    XR_SEPOLIA = 2730
    ELIZABETH_TESTNET = 2731
    ABSTRACT = 2741
    NANON = 2748
    GM_NETWORK_MAINNET = 2777
    MORPH_HOLESKY = 2810
    MORPH = 2818
    HYPERAGI_MAINNET = 2868
    CHIPS_NETWORK = 2882
    BOBA_NETWORK_GOERLI_TESTNET = 2888
    AARMA_MAINNET = 2889
    ELUX_CHAIN = 2907
    HYCHAIN = 2911
    XENON_CHAIN_TESTNET = 2941
    BITYUAN_MAINNET = 2999
    CENNZNET_RATA = 3000
    CENNZNET_NIKAU = 3001
    CANXIUM_MAINNET = 3003
    PLAYA3ULL_GAMES = 3011
    ORLANDO_CHAIN = 3031
    REBUS_TESTNET = 3033
    BIFROST_MAINNET = 3068
    MOVEMENT_EVM = 3073
    XL_NETWORK_TESTNET = 3084
    IMMU3_EVM = 3100
    VULTURE_EVM_BETA = 3102
    SATOSHIVM_ALPHA_MAINNET = 3109
    SATOSHIVM_TESTNET = 3110
    FILECOIN_HYPERSPACE_TESTNET = 3141
    DUBXCOIN_NETWORK = 3269
    DUBXCOIN_TESTNET = 3270
    DEBOUNCE_SUBNET_TESTNET = 3306
    ZCORE_TESTNET = 3331
    ETHSTORAGE_L2_MAINNET = 3332
    ETHSTORAGE_TESTNET = 3333
    WEB3Q_GALILEO = 3334
    ETHSTORAGE_L2_DEVNET = 3335
    ETHSTORAGE_L2_TESTNET = 3336
    ETHSTORAGE_DEVNET = 3337
    PEAQ = 3338
    ETHSTORAGE_MAINNET = 3339
    PARIBU_NET_MAINNET = 3400
    EVOLVE_MAINNET = 3424
    SECURECHAIN_TESTNET = 3434
    LAYEREDGE_TESTNET = 3456
    GTCSCAN = 3490
    PARIBU_NET_TESTNET = 3500
    JFIN_CHAIN = 3501
    JZERO = 3502
    PANDOPROJECT_MAINNET = 3601
    PANDOPROJECT_TESTNET = 3602
    TYCOONCOIN = 3630
    BOTANIX_TESTNET = 3636
    BOTANIX_MAINNET = 3637
    ICHAIN_NETWORK = 3639
    ICHAIN_TESTNET = 3645
    JOULEVERSE_MAINNET = 3666
    BITTEX_MAINNET = 3690
    EMPIRE_NETWORK = 3693
    SENJEPOWERS_TESTNET = 3698
    SENJEPOWERS_MAINNET = 3699
    XPLA_TESTNET = 3701
    CROSSBELL = 3737
    ASTAR_ZKEVM = 3776
    ALVEYCHAIN_MAINNET = 3797
    TANGLE_TESTNET = 3799
    FIRECHAIN_ZKEVM_GHOSTRIDER = 3885
    KALYCHAIN_MAINNET = 3888
    KALYCHAIN_TESTNET = 3889
    DRAC_NETWORK = 3912
    DOS_TESNET = 3939
    DYNO_MAINNET = 3966
    DYNO_TESTNET = 3967
    APEX_TESTNET = 3993
    YUANCHAIN_MAINNET = 3999
    OZONE_CHAIN_MAINNET = 4000
    PEPERIUM_CHAIN_TESTNET = 4001
    FANTOM_TESTNET = 4002
    X1_FASTNET = 4003
    CARBONIUM_TESTNET_NETWORK = 4040
    GAN_TESTNET = 4048
    BOBAOPERA_TESTNET = 4051
    BAHAMUT_OCEAN = 4058
    NAHMII_3_MAINNET = 4061
    NAHMII_3_TESTNET = 4062
    MUSTER_MAINNET = 4078
    TOBE_CHAIN_TESTNET = 4080
    ZEROTH_MAINNET = 4088
    FASTEX_CHAIN_BAHAMUT_OASIS_TESTNET = 4090
    BITINDI_TESTNET = 4096
    BITINDI_MAINNET = 4099
    AIOZ_NETWORK_TESTNET = 4102
    HUMANS_AI_TESTNET = 4139
    TIPBOXCOIN_TESTNET = 4141
    CROSSFI_TESTNET = 4157
    CROSSFI_MAINNET = 4158
    SX_ROLLUP = 4162
    PHI_NETWORK_V1 = 4181
    MERLIN_MAINNET = 4200
    LUKSO_TESTNET = 4201
    LISK_SEPOLIA_TESTNET = 4202
    NEXI_MAINNET = 4242
    NEXI_V2_MAINNET = 4243
    LAIKA_TESTNET = 4269
    ECHOS_CHAIN = 4321
    BOBAFUJI_TESTNET = 4328
    BEAM = 4337
    CREDIT_SMART_CHAIN_MAINNET = 4400
    TESTNET_PIKA = 4422
    HTMLCOIN_MAINNET = 4444
    ORDERLY_SEPOLIA_TESTNET = 4460
    HYDRA_CHAIN = 4488
    EMONEY_NETWORK_TESTNET = 4544
    EMONEY_NETWORK_MAINNET = 4545
    VERY_MAINNET = 4613
    MST_CHAIN = 4646
    GOLD_CHAIN = 4653
    APPCHAIN_TESTNET = 4661
    IOTEX_NETWORK_MAINNET = 4689
    IOTEX_NETWORK_TESTNET = 4690
    MEVERSE_CHAIN_TESTNET = 4759
    BLACKFORT_EXCHANGE_NETWORK_TESTNET = 4777
    WORLD_CHAIN_SEPOLIA_TESTNET = 4801
    GLOBEL_CHAIN = 4893
    VENIDIUM_TESTNET = 4918
    VENIDIUM_MAINNET = 4919
    BLACKFORT_EXCHANGE_NETWORK = 4999
    MANTLE = 5000
    MANTLE_TESTNET = 5001
    TREASURENET_MAINNET_ALPHA = 5002
    MANTLE_SEPOLIA_TESTNET = 5003
    TREASURENET_TESTNET = 5005
    ONIGIRI_TEST_SUBNET = 5039
    ONIGIRI_SUBNET = 5040
    SKATE_MAINNET = 5050
    NOLLIE_SKATECHAIN_TESTNET = 5051
    PIONEER_ZERO_CHAIN = 5080
    PIONEER_CHAIN_TESTNET = 5090
    SYNDICATE_TESTNET = 5100
    SYNDICATE_FRAME_CHAIN = 5101
    SIC_TESTNET = 5102
    COORDINAPE_TESTNET = 5103
    CHARMVERSE_TESTNET = 5104
    SUPERLOYALTY_TESTNET = 5105
    AZRA_TESTNET = 5106
    HAM = 5112
    CITREA_TESTNET = 5115
    MECHAIN_TESTNET = 5151
    BAHAMUT = 5165
    SMART_LAYER_NETWORK = 5169
    TLCHAIN_NETWORK_MAINNET = 5177
    ERASWAP_MAINNET = 5197
    HUMANODE_MAINNET = 5234
    FIRECHAIN_MAINNET_OLD = 5290
    UZMI_NETWORK_MAINNET = 5315
    OPTRUST_TESTNET = 5317
    ITX_TESTNET = 5321
    SUPERSEED = 5330
    NETSBO = 5333
    TRITANIUM_TESTNET = 5353
    SETTLUS_TESTNET = 5372
    SETTLUS_SEPOLIA_TESTNET = 5373
    EDEXA_MAINNET = 5424
    EGOCHAIN = 5439
    POINTPAY_MAINNET = 5511
    VEX_EVM_TESTNET = 5522
    DUCKCHAIN_MAINNET = 5545
    NAHMII_2_MAINNET = 5551
    NAHMII_2_TESTNET = 5553
    CHAIN_VERSE_MAINNET = 5555
    OPBNB_TESTNET = 5611
    ARCTURUS_TESTNEET = 5615
    ARCTURUS_CHAIN_TESTNET = 5616
    QIE_BLOCKCHAIN = 5656
    FILENOVA_TESTNET = 5675
    TANSSI_DEMO = 5678
    SYSCOIN_TANENBAUM_TESTNET = 5700
    HIKA_NETWORK_TESTNET = 5729
    SATOSHICHAIN_TESTNET = 5758
    TANGLE = 5845
    ONTOLOGY_TESTNET = 5851
    CHANG_CHAIN_FOUNDATION_MAINNET = 5858
    WEGOCHAIN_RUBIDIUM_MAINNET = 5869
    BOUNCEBIT_TESTNET = 6000
    BOUNCEBIT_MAINNET = 6001
    BC_HYPER_CHAIN_TESTNET = 6060
    TRES_TESTNET = 6065
    TRES_MAINNET = 6066
    CASCADIA_TESTNET = 6102
    UPTN_TESTNET = 6118
    UPTN = 6119
    RAILS = 6278
    LAOS = 6283
    AURA_EUPHORIA_TESTNET = 6321
    AURA_MAINNET = 6322
    DIGIT_SOUL_SMART_CHAIN = 6363
    CONNEXT_SEPOLIA = 6398
    PEERPAY = 6502
    FLAMMA_TESTNET = 6550
    SCOLCOIN_WEICHAIN_TESTNET = 6552
    FOX_TESTNET_NETWORK = 6565
    PIXIE_CHAIN_MAINNET = 6626
    LATEST_CHAIN_TESTNET = 6660
    CYBRIA_MAINNET = 6661
    CYBRIA_TESTNET = 6666
    STORCHAIN = 6667
    EDGE_MATRIX_CHAIN = 6678
    IRISHUB = 6688
    OX_CHAIN = 6699
    PAXB_MAINNET = 6701
    COMPVERSE_MAINNET = 6779
    GOLD_SMART_CHAIN_MAINNET = 6789
    RACE_MAINNET = 6805
    RACE_TESTNET = 6806
    POOLS_MAINNET = 6868
    MTT_MAINNET = 6880
    NIBIRU_MAINNET = 6900
    XYL_TESTNET = 6934
    LAIKA_MAINNET = 6942
    TOMB_CHAIN_MAINNET = 6969
    POLYSMARTCHAIN = 6999
    ZETACHAIN_MAINNET = 7000
    ZETACHAIN_TESTNET = 7001
    BST_CHAIN = 7007
    ELLA_THE_HEART = 7027
    PLANQ_MAINNET = 7070
    PLANQ_ATLAS_TESTNET = 7077
    NUME = 7100
    _0XL3 = 7117
    HELP_THE_HOMELESS = 7118
    BITROCK_MAINNET = 7171
    EXSAT_MAINNET = 7200
    NIBIRU_TESTNET_1 = 7210
    NIBIRU_DEVNET_3 = 7222
    ZEUS_TESTNET = 7244
    XPLA_VERSE = 7300
    KLYNTAR = 7331
    HORIZEN_EON_MAINNET = 7332
    SHYFT_MAINNET = 7341
    RABA_NETWORK_MAINNET = 7484
    MEVERSE_CHAIN_MAINNET = 7518
    CYBER_MAINNET = 7560
    ADIL_TESTNET = 7575
    ADIL_CHAIN_V2_MAINNET = 7576
    THE_ROOT_NETWORK_MAINNET = 7668
    THE_ROOT_NETWORK_PORCINI_TESTNET = 7672
    CANTO = 7700
    CANTO_TESNET = 7701
    PHRON_TESTNET = 7744
    BITROCK_TESTNET = 7771
    GDCC_MAINNET = 7774
    GDCC_TESTNET = 7775
    PANDASEA_MAINNET = 7776
    RISE_OF_THE_WARBOTS_TESTNET = 7777
    ORENIUM_MAINNET_PROTOCOL = 7778
    OPENEX_LONG_TESTNET = 7798
    MAALCHAIN_TESTNET = 7860
    MAALCHAIN_V2 = 7862
    MAALCHAIN_TESTNET_V2 = 7863
    HAZLOR_TESTNET = 7878
    VEXON_TESTNET = 7879
    KINTO_MAINNET = 7887
    ARDENIUM_ATHENA = 7895
    ARENA_Z = 7897
    DOT_BLOX = 7923
    MO_MAINNET = 7924
    DOS_CHAIN = 7979
    TELEPORT = 8000
    TELEPORT_TESTNET = 8001
    POLYNOMIAL = 8008
    ISUNCOIN_MAINNET = 8017
    MDGL_TESTNET = 8029
    BOAT_MAINNET = 8047
    KARAK_SEPOLIA = 8054
    SHARDEUM_LIBERTY_1_X = 8080
    SHARDEUM_LIBERTY_2_X = 8081
    SHARDEUM_SPHINX_1_X = 8082
    BITCOIN_CHAIN = 8086
    E_DOLLAR = 8087
    STREAMUX_BLOCKCHAIN = 8098
    ZENCHAIN = 8108
    QITMEER_NETWORK_TESTNET = 8131
    QITMEER_NETWORK_MIXNET = 8132
    QITMEER_NETWORK_PRIVNET = 8133
    AMANA = 8134
    FLANA = 8135
    MIZANA = 8136
    TESTNET_BEONE_CHAIN = 8181
    TORUS_MAINNET = 8192
    TORUS_TESTNET = 8194
    KAIA_MAINNET = 8217
    SPACE_SUBNET = 8227
    BLOCKTON_BLOCKCHAIN = 8272
    KORTHOTEST = 8285
    LORENZO = 8329
    B3 = 8333
    DRACONES_FINANCIAL_SERVICES = 8387
    ZENCHAIN_TESTNET = 8408
    THAT_MAINNET = 8428
    BASE = 8453
    CHAKRA_TESTNET = 8545
    TOKI_NETWORK = 8654
    TOKI_TESTNET = 8655
    HELA_OFFICIAL_RUNTIME_MAINNET = 8668
    TOOL_GLOBAL_MAINNET = 8723
    TOOL_GLOBAL_TESTNET = 8724
    STORAGECHAIN_MAINNET = 8726
    STORAGECHAIN_TESTNET = 8727
    BULLIONS_SMART_CHAIN = 8732
    ALPH_NETWORK = 8738
    TMY_CHAIN = 8768
    IOTA_EVM = 8822
    HYDRA_CHAIN_TESTNET = 8844
    MARO_BLOCKCHAIN_MAINNET = 8848
    SUPERLUMIO = 8866
    LIF3_CHAIN = 8869
    UNIQUE = 8880
    QUARTZ_BY_UNIQUE = 8881
    OPAL_TESTNET_BY_UNIQUE = 8882
    SAPPHIRE_BY_UNIQUE = 8883
    AVENIUM_TESTNET = 8886
    XANACHAIN = 8888
    VYVO_SMART_CHAIN = 8889
    ORENIUM_TESTNET_PROTOCOL = 8890
    MAMMOTH_MAINNET = 8898
    JIBCHAIN_L1 = 8899
    ALGEN = 8911
    ALGEN_TESTNET = 8912
    ALGEN_LAYER2 = 8921
    ALGEN_LAYER2_TESTNET = 8922
    GIANT_MAMMOTH_MAINNET = 8989
    BLOXBERG = 8995
    EVMOS_TESTNET = 9000
    EVMOS = 9001
    SHIDO_TESTNET_BLOCK = 9007
    SHIDO_MAINNET_BLOCK = 9008
    BERYLBIT_MAINNET = 9012
    NEXA_TESTNET_BLOCK = 9024
    NEXA_MAINNET_BLOCK = 9025
    APEX_FUSION_NEXUS_MAINNET = 9069
    APEX_FUSION_NEXUS_TESTNET = 9070
    KPA_SMART_CHAIN_TESTNET = 9091
    GENESIS_COIN = 9100
    RINIA_TESTNET_OLD = 9170
    CODEFIN_MAINNET = 9223
    GALACTICA_RETICULUM = 9302
    DOGCOIN_TESTNET = 9339
    OASYS_TESTNET = 9372
    DELA_SEPOLIA_TESTNET = 9393
    EVOKE_MAINNET = 9395
    WEAVEVM_TESTNET = 9496
    RANGERS_PROTOCOL_TESTNET_ROBIN = 9527
    QEASYWEB3_TESTNET = 9528
    NEONLINK_TESTNET = 9559
    OORT_MAINNETDEV = 9700
    BOBA_BNB_TESTNET = 9728
    MAINNETZ_TESTNET = 9768
    PEPENETWORK_MAINNET = 9779
    TABI_TESTNETV2 = 9788
    TABI_TESTNET = 9789
    CARBON_EVM = 9790
    CARBON_EVM_TESTNET = 9792
    OPTIMUSZ7_MAINNET = 9797
    IMPERIUM_TESTNET = 9818
    IMPERIUM_MAINNET = 9819
    BINARYCHAIN_TESTNET = 9876
    DOGELAYER_MAINNET = 9888
    ARENA_Z_TESTNET = 9897
    LARISSA_CHAIN = 9898
    ZYTRON_LINEA_MAINNET = 9901
    ESPENTO_MAINNET = 9911
    UXER_TESTNET_NETWORK = 9966
    MIND_SMART_CHAIN_TESTNET = 9977
    COMBO_MAINNET = 9980
    VOLLEY_MAINNET = 9981
    MFEV_CHAIN_MAINNET = 9982
    AGUNG_NETWORK = 9990
    MIND_SMART_CHAIN_MAINNET = 9996
    ALTLAYER_TESTNET = 9997
    ZTC_MAINNET = 9998
    MYOWN_TESTNET = 9999
    SMART_BITCOIN_CASH = 10000
    SMART_BITCOIN_CASH_TESTNET = 10001
    WARDEN_TESTNET = 10010
    GON_CHAIN = 10024
    AEON_CHAIN = 10025
    JAPAN_OPEN_CHAIN_TESTNET = 10081
    SJATSH = 10086
    METANOVA_VERSE = 10096
    BLOCKCHAIN_GENESIS_MAINNET = 10101
    MONAD_TESTNET = 10143
    GNOSIS_CHIADO_TESTNET = 10200
    MAXXCHAIN_MAINNET = 10201
    GLSCAN = 10222
    ARTHERA_MAINNET = 10242
    ARTHERA_TESTNET = 10243
    _0XTADE = 10248
    TAO_EVM_MAINNET = 10321
    TAO_EVM_TESTNET = 10324
    WORLDLAND_TESTNET = 10395
    NUMBERS_MAINNET = 10507
    NUMBERS_TESTNET = 10508
    CRYPTOCOINPAY = 10823
    LAMINA1 = 10849
    LAMINA1_IDENTITY = 10850
    GAMESWIFT_CHAIN_TESTNET = 10888
    QUADRANS_BLOCKCHAIN = 10946
    QUADRANS_BLOCKCHAIN_TESTNET = 10947
    KB_CHAIN = 11000
    SHAPE_SEPOLIA_TESTNET = 11011
    BOOL_NETWORK_BETA_MAINNET = 11100
    ASTRA = 11110
    WAGMI = 11111
    ASTRA_TESTNET = 11115
    HASHBIT_MAINNET = 11119
    ABSTRACT_TESTNET = 11124
    SHINE_CHAIN = 11221
    JIRITSU_TESTNET_SUBNET = 11227
    HAQQ_NETWORK = 11235
    SHYFT_TESTNET = 11437
    BEVM_MAINNET = 11501
    BEVM_TESTNET = 11503
    SATSCHAIN = 11521
    SARDIS_TESTNET = 11612
    ARTELA_TESTNET = 11822
    SANTIMENT_INTELLIGENCE_NETWORK_DEPRECATED = 11888
    POLYGON_SUPERNET_ARIANEE = 11891
    FUSE_TESTNET = 12001
    SATOSHICHAIN_MAINNET = 12009
    ATERNOS = 12020
    SINGULARITY_ZERO_TESTNET = 12051
    SINGULARITY_ZERO_MAINNET = 12052
    BRC_CHAIN_MAINNET = 12123
    FIBONACCI_MAINNET = 12306
    BLG_TESTNET = 12321
    L3X_PROTOCOL = 12324
    L3X_PROTOCOL_TESTNET = 12325
    STEP_TESTNET = 12345
    GDPR_MAINNET = 12358
    RSS3_VSL_MAINNET = 12553
    RIKEZA_NETWORK_TESTNET = 12715
    PLAYDAPP_TESTNET = 12781
    QUANTUM_CHAIN_TESTNET = 12890
    PLAYFAIR_TESTNET_SUBNET = 12898
    SPS = 13000
    CREDIT_SMART_CHAIN = 13308
    BEAM_TESTNET = 13337
    CANNON_TESTNET = 13370
    IMMUTABLE_ZKEVM = 13371
    PHOENIX_MAINNET = 13381
    MASA = 13396
    IMMUTABLE_ZKEVM_TESTNET = 13473
    GRAVITY_ALPHA_TESTNET_SEPOLIA = 13505
    KRONOBIT_MAINNET = 13600
    GAME7_TESTNET = 13746
    SUSONO = 13812
    SPS_TESTNET = 14000
    ZEROTH_TESTNET = 14088
    BITHARVEST_CHAIN_MAINNET = 14149
    EVOLVE_TESTNET = 14324
    VITRUVEO_TESTNET = 14333
    VANA_MOKSHA_TESTNET = 14800
    VANA_SATORI_TESTNET = 14801
    HUMANODE_TESTNET_5_ISRAFEL = 14853
    IMMUTABLE_ZKEVM_DEVNET = 15003
    POODL_TESTNET = 15257
    POODL_MAINNET = 15259
    KYMTC_MAINNET = 15430
    LOOPNETWORK_MAINNET = 15551
    TRUST_EVM_TESTNET = 15555
    EOS_EVM_NETWORK_TESTNET = 15557
    METADOT_MAINNET = 16000
    METADOT_TESTNET = 16001
    DEFIVERSE_MAINNET = 16116
    CYPHERIUM_MAINNET = 16166
    PLYR_PHI = 16180
    EVENTUM_TESTNET = 16182
    INCENTIV_DEVNET = 16350
    PIVOTAL_SEPOLIA = 16481
    GENESYS_MAINNET = 16507
    _0G_NEWTON_TESTNET = 16600
    IRISHUB_TESTNET = 16688
    AIRDAO_MAINNET = 16718
    IVAR_CHAIN_TESTNET = 16888
    HOLESKY = 17000
    REDSTONE_HOLESKY_TESTNET = 17001
    GARNET_HOLESKY = 17069
    ONCHAIN_POINTS = 17071
    DEFIVERSE_TESTNET = 17117
    G8CHAIN_MAINNET = 17171
    ECLIPSE_SUBNET = 17172
    PALETTE_CHAIN_TESTNET = 17180
    KONET_MAINNET = 17217
    EOS_EVM_NETWORK = 17777
    FRONTIER_OF_DREAMS_TESTNET = 18000
    SMART_TRADE_NETWORKS = 18122
    PROOF_OF_MEMES = 18159
    G8CHAIN_TESTNET = 18181
    UNREAL_OLD = 18231
    UNREAL = 18233
    MXC_ZKEVM_MOONCHAIN = 18686
    EXPCHAIN_TESTNET = 18880
    TITAN_TKX = 18888
    TITAN_TKX_TESTNET = 18889
    HOME_VERSE_MAINNET = 19011
    BLOCKX_ATLANTIS_TESTNET = 19077
    LOCACHAIN_MAINNET = 19180
    BLOCKX_MAINNET = 19191
    DECENTRACONNECT_SOCIAL = 19224
    SEC_TESTNET = 19515
    SEC_MAINNET = 19516
    MAGNET_NETWORK = 19527
    ZYTRON_LINEA_TESTNET = 19546
    LBRY_MAINNET = 19600
    ASTRA_SEPOLIA = 19777
    BTCIX_NETWORK = 19845
    CAMELARK_MAINNET = 20001
    NIZA_CHAIN_MAINNET = 20041
    NIZA_CHAIN_TESTNET = 20073
    MONAD_DEVNET = 20143
    CALLISTO_TESTNET = 20729
    P12_CHAIN = 20736
    JONO11_SUBNET = 20765
    C4EI = 21004
    RIVEST_TESTNET = 21097
    ALL_ABOUT_HEALTHY = 21133
    _1MONEY_NETWORK_MAINNET = 21210
    DCPAY_MAINNET = 21223
    DCPAY_TESTNET = 21224
    CENNZNET_AZALEA = 21337
    LESTNET = 21363
    OMCHAIN_MAINNET = 21816
    BSL_MAINNET = 21912
    TAYCAN = 22023
    AIRDAO_TESTNET = 22040
    NAUTILUS_MAINNET = 22222
    GOLDXCHAIN_TESTNET = 22324
    MAP_PROTOCOL = 22776
    ANTOFY_TESTNET = 23006
    OPSIDE_TESTNET = 23118
    OASIS_SAPPHIRE = 23294
    OASIS_SAPPHIRE_TESTNET = 23295
    DREYERX_MAINNET = 23451
    DREYERX_TESTNET = 23452
    BLAST_TESTNET = 23888
    KYMTC_TESTNET = 24076
    AMAUTI = 24116
    WEBCHAIN = 24484
    MINTME_COM_COIN = 24734
    LIQUIDLAYER_MAINNET = 25186
    EVERCLEAR_MAINNET = 25327
    ALVEYCHAIN_TESTNET = 25839
    HAMMER_CHAIN_MAINNET = 25888
    BITKUB_CHAIN_TESTNET = 25925
    FERRUM_TESTNET = 26026
    DUCATUSX_TESTNET = 26482
    DUCATUSX = 26483
    HERTZ_NETWORK_MAINNET = 26600
    OASISCHAIN_MAINNET = 26863
    KLAOS_NOVA = 27181
    NANON_SEPOLIA = 27483
    ZEROONE_MAINNET_SUBNET = 27827
    VIZING_TESTNET = 28516
    VIZING_MAINNET = 28518
    OPTIMISM_BEDROCK_GOERLI_ALPHA_TESTNET = 28528
    BOBA_SEPOLIA = 28882
    HYCHAIN_TESTNET = 29112
    NEXA_METANET = 29223
    NEXA_METATEST = 29225
    KAICHAIN_TESTNET = 29536
    MCH_VERSE_MAINNET = 29548
    QCHAIN_MAINNET = 30000
    PIECE_TESTNET = 30067
    MIYOU_MAINNET = 30088
    CERIUM_TESTNET = 30103
    MOVEMENT_EVM_LEGACY = 30730
    MOVEMENT_EVM_DEVNET = 30731
    MOVEMENT_EVM_TESTNET = 30732
    ETHERSOCIAL_NETWORK = 31102
    CLOUDTX_MAINNET = 31223
    CLOUDTX_TESTNET = 31224
    GOCHAIN_TESTNET = 31337
    EVOKE_TESTNET = 31414
    WIREX_PAY_MAINNET = 31415
    MEZO_MATSNET_TESTNET = 31611
    XCHAIN_MAINNET = 31753
    XCHAIN_TESTNET = 31754
    W3GAMEZ_HOLESKY_TESTNET = 32001
    SANTIMENT_INTELLIGENCE_NETWORK = 32382
    BITGERT_MAINNET = 32520
    FUSION_MAINNET = 32659
    ZILLIQA_EVM = 32769
    ZILLIQA_2_EVM_PROTO_MAINNET = 32770
    ZILLIQA_EVM_ISOLATED_SERVER = 32990
    ENTANGLE_MAINNET = 33033
    ZILLIQA_EVM_TESTNET = 33101
    ZILLIQA_2_EVM_PROTO_TESTNET = 33103
    CURTIS = 33111
    ENTANGLE_TESTNET = 33133
    APECHAIN = 33139
    CLOUDVERSE_SUBNET = 33210
    AVES_MAINNET = 33333
    ZILLIQA_EVM_DEVNET = 33385
    SLINGSHOT = 33401
    ZILLIQA_2_EVM_DEVNET = 33469
    FUNKI = 33979
    MODE = 34443
    ZEUS_MAINNET = 34504
    J2O_TARO = 35011
    Q_MAINNET = 35441
    Q_TESTNET = 35443
    LENS_TESTNET = 37111
    CONNECTORMANAGER = 38400
    CONNECTORMANAGER_ROBIN = 38401
    PRM_MAINNET = 39656
    ENERGI_MAINNET = 39797
    OHO_MAINNET = 39815
    DIV_CHAIN = 40000
    ALEPH_ZERO_EVM = 41455
    OPULENT_X_BETA = 41500
    EDU_CHAIN = 41923
    PEGGLECOIN = 42069
    AGENTLAYER_TESTNET = 42072
    ARBITRUM_ONE = 42161
    ARBITRUM_NOVA = 42170
    CELO_MAINNET = 42220
    OASIS_EMERALD_TESTNET = 42261
    OASIS_EMERALD = 42262
    GOLDXCHAIN_MAINNET = 42355
    ASSET_CHAIN_MAINNET = 42420
    ASSET_CHAIN_TESTNET = 42421
    ZKFAIR_MAINNET = 42766
    ETHERLINK_MAINNET = 42793
    GESOTEN_VERSE_TESTNET = 42801
    KINTO_TESTNET = 42888
    ATHEREUM = 43110
    HEMI_NETWORK = 43111
    AVALANCHE_FUJI_TESTNET = 43113
    AVALANCHE_C_CHAIN = 43114
    BOBA_AVAX = 43288
    FORMICARIUM = 43521
    ZKFAIR_TESTNET = 43851
    FRENCHAIN = 44444
    QUANTUM_NETWORK = 44445
    CELO_ALFAJORES_TESTNET = 44787
    AUTOBAHN_NETWORK = 45000
    SWAMPS_L2 = 45454
    DEELANCE_MAINNET = 45510
    BLESSNET = 45513
    FUSION_TESTNET = 46688
    NEO_X_MAINNET = 47763
    REDEFI_LAYER_1 = 47803
    REI_NETWORK = 47805
    SPACE_SUBNET_TESTNET = 48795
    ZIRCUIT_TESTNET = 48899
    ZIRCUIT_MAINNET = 48900
    WIRESHAPE_FLORIPA_TESTNET = 49049
    BIFROST_TESTNET = 49088
    GUNZ_TESTNET = 49321
    ENERGI_TESTNET = 49797
    LIVEPLEX_ORACLEEVM = 50001
    YOOLDO_VERSE_MAINNET = 50005
    YOOLDO_VERSE_TESTNET = 50006
    GTON_TESTNET = 50021
    SOPHON = 50104
    REDDIO_DEVNET = 50341
    ERBIE_MAINNET = 50888
    LUMOZ_TESTNET_ALPHA = 51178
    SARDIS_MAINNET = 51712
    ELECTRONEUM_MAINNET = 52014
    CYTONIC_TESTNET = 52225
    DOID = 53277
    SUPERSEED_SEPOLIA_TESTNET = 53302
    DODOCHAIN_TESTNET = 53457
    DFK_CHAIN = 53935
    OVERPROTOCOL_MAINNET = 54176
    HAQQ_CHAIN_TESTNET = 54211
    TORONET_TESTNET = 54321
    TITAN = 55004
    TITAN_SEPOLIA = 55007
    SUPERPOSITION = 55244
    PHOTON_AURORA_TESTNET = 55551
    REI_CHAIN_MAINNET = 55555
    REI_CHAIN_TESTNET = 55556
    FLAMMA_MAINNET = 55614
    LAMBDA_CHAIN_MAINNET = 56026
    BOBA_BNB_MAINNET = 56288
    TESTNET_ZEROONE_SUBNET = 56400
    VELO_LABS_MAINNET = 56789
    DOID_TESTNET = 56797
    ROLLUX_TESTNET = 57000
    SONIC_BLAZE_TESTNET = 57054
    INK = 57073
    COINSEC_NETWORK = 57451
    SEPOLIA_PGN_PUBLIC_GOODS_NETWORK = 58008
    LUMOZ_QUIDDITCH_TESTNET = 58680
    LINEA_GOERLI = 59140
    LINEA_SEPOLIA = 59141
    LINEA = 59144
    METIS_SEPOLIA_TESTNET = 59902
    GENESYS_CODE_MAINNET = 59971
    THINKIUM_TESTNET_CHAIN_0 = 60000
    THINKIUM_TESTNET_CHAIN_1 = 60001
    THINKIUM_TESTNET_CHAIN_2 = 60002
    THINKIUM_TESTNET_CHAIN_103 = 60103
    BOB = 60808
    ORANGE_CHAIN_MAINNET = 61022
    TREASURE = 61166
    KAICHAIN = 61406
    AXELCHAIN_DEV_NET = 61800
    ETICA_MAINNET = 61803
    DOKEN_SUPER_CHAIN_MAINNET = 61916
    OPTOPIA_TESTNET = 62049
    OPTOPIA_MAINNET = 62050
    TIKTRIX_TESTNET = 62092
    CITREA_DEVNET = 62298
    CELO_BAKLAVA_TESTNET = 62320
    MULTIVAC_MAINNET = 62621
    PLYR_TAU_TESTNET = 62831
    LAOS_SIGMA_TESTNET = 62850
    ESYNC_NETWORK_MAINNET = 63000
    ECREDITS_TESTNET = 63001
    ESYNC_NETWORK_TESTNET = 63002
    GEIST_MAINNET = 63157
    CRATD2C_TESTNET = 65349
    VECNO_MAINNET = 65357
    SCOLCOIN_MAINNET = 65450
    AUTOMATA_MAINNET = 65536
    CREATOR_CHAIN_TESTNET = 66665
    JANUS_TESTNET = 66988
    SIRIUSNET = 67390
    COSMIC_CHAIN = 67588
    DM2_VERSE_MAINNET = 68770
    DM2_VERSE_TESTNET = 68775
    CONDRIEU = 69420
    THINKIUM_MAINNET_CHAIN_0 = 70000
    THINKIUM_MAINNET_CHAIN_1 = 70001
    THINKIUM_MAINNET_CHAIN_2 = 70002
    THINKIUM_MAINNET_CHAIN_103 = 70103
    PROOF_OF_PLAY_APEX = 70700
    PROOF_OF_PLAY_BOSS = 70701
    GUAPCOINX = 71111
    WADZCHAIN_TESTNET = 71117
    POLYJUICE_TESTNET = 71393
    GODWOKEN_MAINNET = 71402
    CAGA_CRYPTO_ANKARA_TESTNET = 72778
    GROK_CHAIN_MAINNET = 72992
    ICB_TESTNET = 73114
    ICB_NETWORK = 73115
    ENERGY_WEB_VOLTA_TESTNET = 73799
    MIXIN_VIRTUAL_MACHINE = 73927
    RESINCOIN_MAINNET = 75000
    APPLAYER_TESTNET = 75338
    GEEK_VERSE_MAINNET = 75512
    GEEK_VERSE_TESTNET = 75513
    BORACHAIN_MAINNET = 77001
    FOUNDRY_CHAIN_TESTNET = 77238
    VENTION_SMART_CHAIN_MAINNET = 77612
    CYCLE_NETWORK_MAINNET_SAILBOAT = 77677
    TORONET_MAINNET = 77777
    FIRENZE_TEST_NETWORK = 78110
    DRAGONFLY_MAINNET_HEXAPOD = 78281
    AMPLIFY_SUBNET = 78430
    BULLETIN_SUBNET = 78431
    CONDUIT_SUBNET = 78432
    VANGUARD = 78600
    GOLD_SMART_CHAIN_TESTNET = 79879
    MUMBAI = 80001
    AMOY = 80002
    POLYNOMIA_SEPOLIA = 80008
    BERACHAIN_BARTIO = 80084
    BERACHAIN_ARTIO = 80085
    HIZOCO_MAINNET = 80096
    NORDEK_MAINNET = 81041
    AMANA_TESTNET = 81341
    AMANA_MIXNET = 81342
    AMANA_PRIVNET = 81343
    FLANA_TESTNET = 81351
    FLANA_MIXNET = 81352
    FLANA_PRIVNET = 81353
    MIZANA_TESTNET = 81361
    MIZANA_MIXNET = 81362
    MIZANA_PRIVNET = 81363
    BLAST = 81457
    QUANTUM_CHAIN_MAINNET = 81720
    SMART_LAYER_NETWORK_TESTNET = 82459
    XPROTOCOL_TESTNET = 83144
    ESA = 83278
    ZEDXION = 83872
    BASE_GOERLI_TESTNET = 84531
    BASE_SEPOLIA_TESTNET = 84532
    O_CHAIN = 84841
    AERIE_NETWORK = 84886
    GDPR_TESTNET = 85321
    CYBERTRUST = 85449
    NAUTILUS_PROTEUS_TESTNET = 88002
    INOAI = 88559
    ZKASINO_MAINNET = 88800
    UNIT_ZERO_MAINNET = 88811
    UNIT_ZERO_TESTNET = 88817
    UNIT_ZERO_STAGENET = 88819
    MATR1X_TESTNET = 88866
    CHILIZ_SCOVILLE_TESTNET = 88880
    CHILIZ_SPICY_TESTNET = 88882
    CHILIZ_CHAIN_MAINNET = 88888
    UNITE = 88899
    F_XCORE_TESTNET_NETWORK = 90001
    UBIT_SMARTCHAIN_MAINNET = 90002
    BEVERLY_HILLS = 90210
    CAMP_TESTNET = 90354
    NAUTILUS_TRITION_CHAIN = 91002
    METADAP_ENTERPRISE_MAINNET = 91120
    COMBO_TESTNET = 91715
    LAMBDA_TESTNET = 92001
    LIQUIDLAYER_TESTNET = 93572
    STRATOVM_TESTNET = 93747
    SRICHAIN = 95432
    LUX_TESTNET = 96368
    LUX_MAINNET = 96369
    MANTIS_TESTNET_HEXAPOD = 96970
    TETRON_TESTNET_SMART_CHAIN = 97053
    TETRON_SMART_CHAIN = 97055
    BOBA_BNB_MAINNET_OLD = 97288
    SLINGSHOT_TESTNET = 97435
    GREEN_CHAIN_TESTNET = 97531
    METABENZ_CHAIN = 97766
    OPTIMUSZ7_TESTNET = 97970
    PLUME_DEVNET = 98864
    PLUME_MAINNET = 98865
    EBI_CHAIN = 98881
    SUPERPOSITION_TESTNET = 98985
    ELIBERTY_TESTNET = 99099
    EDGE_MATRIX_CHAIN_TESTNET = 99876
    UB_SMART_CHAIN_TESTNET = 99998
    UB_SMART_CHAIN = 99999
    QUARKCHAIN_MAINNET_ROOT = 100000
    QUARKCHAIN_MAINNET_SHARD_0 = 100001
    QUARKCHAIN_MAINNET_SHARD_1 = 100002
    QUARKCHAIN_MAINNET_SHARD_2 = 100003
    QUARKCHAIN_MAINNET_SHARD_3 = 100004
    QUARKCHAIN_MAINNET_SHARD_4 = 100005
    QUARKCHAIN_MAINNET_SHARD_5 = 100006
    QUARKCHAIN_MAINNET_SHARD_6 = 100007
    QUARKCHAIN_MAINNET_SHARD_7 = 100008
    VECHAIN = 100009
    VECHAIN_TESTNET = 100010
    QUARKCHAIN_L2_MAINNET = 100011
    DEPRECATED_CHI = 100100
    GLOBAL_TRUST_NETWORK = 101010
    CREDITCOIN = 102030
    CREDITCOIN_TESTNET = 102031
    CREDITCOIN_DEVNET = 102032
    CRYSTALEUM = 103090
    MASA_TESTNET = 103454
    KASPACLASSIC_MAINNET = 104566
    STRATIS_MAINNET = 105105
    BROCHAIN_MAINNET = 108801
    QUARKCHAIN_DEVNET_ROOT = 110000
    QUARKCHAIN_DEVNET_SHARD_0 = 110001
    QUARKCHAIN_DEVNET_SHARD_1 = 110002
    QUARKCHAIN_DEVNET_SHARD_2 = 110003
    QUARKCHAIN_DEVNET_SHARD_3 = 110004
    QUARKCHAIN_DEVNET_SHARD_4 = 110005
    QUARKCHAIN_DEVNET_SHARD_5 = 110006
    QUARKCHAIN_DEVNET_SHARD_6 = 110007
    QUARKCHAIN_DEVNET_SHARD_7 = 110008
    QUARKCHAIN_L2_TESTNET = 110011
    MARS_CREDIT = 110110
    SIBERIUM_TEST_NETWORK = 111000
    SIBERIUM_NETWORK = 111111
    RE_AL = 111188
    METACHAIN_ONE_MAINNET = 112358
    METADAP_ENTERPRISE_TESTNET = 119139
    GEMCHAIN = 123321
    ADIL_DEVNET = 123456
    MITOSIS_TESTNET = 124832
    ETHERLINK_TESTNET = 128123
    ODYSSEY_CHAIN_TESTNET = 131313
    ETND_CHAIN_MAINNETS = 131419
    FORM_TESTNET = 132902
    MAGAPE_TESTNET = 141319
    BITHARVEST_CHAIN_TESTNET = 141491
    ICPLAZA_MAINNET = 142857
    ODYSSEY_CHAIN_MAINNET = 153153
    CRYPTOX = 158245
    XCOIN = 158345
    PLAYFI_MAINNET = 161212
    ECLAT_MAINNET = 165279
    TAIKO_MAINNET = 167000
    TAIKO_ALPHA_2_TESTNET = 167004
    TAIKO_GRIMSVOTN_L2 = 167005
    TAIKO_ELDFELL_L3 = 167006
    TAIKO_JOLNIR_L2 = 167007
    TAIKO_KATLA_L2 = 167008
    TAIKO_HEKLA_L2 = 167009
    ZCHAINS = 168168
    FAIR_TESTNET = 171000
    WADZCHAIN_MAINNET = 171717
    CHRONICLE_LIT_PROTOCOL_TESTNET = 175177
    CHRONICLE_YELLOWSTONE_LIT_PROTOCOL_TESTNET = 175188
    BITICA_CHAIN_MAINNET = 188710
    CONDOR_TEST_NETWORK = 188881
    MIND_NETWORK_TESTNET = 192940
    R0AR_CHAIN = 193939
    MAZZE_TESTNET = 199991
    XFAIR_AI_TESTNET = 200000
    MILKOMEDA_C1_TESTNET = 200101
    ZOO_MAINNET = 200200
    MILKOMEDA_A1_TESTNET = 200202
    AKROMA = 200625
    BITLAYER_TESTNET = 200810
    BITLAYER_MAINNET = 200901
    ALAYA_MAINNET = 201018
    ALAYA_DEV_TESTNET = 201030
    MYTHICAL_CHAIN = 201804
    DECIMAL_SMART_CHAIN_TESTNET = 202020
    DUCKCHAIN_TESTNET = 202105
    BETHEL_SYDNEY = 202202
    X1_DEVNET = 202212
    YMTECH_BESU_TESTNET = 202401
    BLOCKFIT = 202424
    JELLIE = 202624
    X1_NETWORK = 204005
    AURORIA_TESTNET = 205205
    GITAGI_ATLAS_TESTNET = 210049
    SORIAN = 210209
    SORIAN_TESTNET = 210210
    PLATON_MAINNET = 210425
    LITENTRY = 212013
    MAS_MAINNET = 220315
    REAPCHAIN_MAINNET = 221230
    REAPCHAIN_TESTNET = 221231
    HYDRADX = 222222
    DEEPL_MAINNET = 222555
    DEEPL_TESTNET = 222666
    TAF_ECO_CHAIN_MAINNET = 224168
    CONET_SEBOLIA_TESTNET = 224422
    CONET_HOLESKY = 224433
    ABYSS_PROTOCOL = 229772
    HASHKEY_CHAIN_TESTNET_DISCARD = 230315
    HAYMO_TESTNET = 234666
    ORANGE_CHAIN_TESTNET = 240515
    ANOMALY_ANDROMEDA_TESTNET = 241120
    ARTIS_SIGMA1 = 246529
    ARTIS_TESTNET_TAU1 = 246785
    SAAKURU_TESTNET = 247253
    CMP_MAINNET = 256256
    ECLAT_TESTNET = 262371
    GEAR_ZERO_NETWORK_TESTNET = 266256
    EGONCOIN_TESTNET = 271271
    NXY_AREA_51 = 272247
    NXY_OASIS = 272520
    SOCIAL_SMART_CHAIN_MAINNET = 281121
    ATHENE_PARTHENON = 281123
    ZILLION_SEPOLIA_TESTNET = 282828
    CIPHEREM_TESTNET = 292003
    ONE_WORLD_CHAIN_MAINNET = 309075
    SAHARAAI_TESTNET = 313313
    FILECOIN_CALIBRATION_TESTNET = 314159
    PAREX_MAINNET = 322202
    BLOOM_GENESIS_TESTNET = 323213
    CAMP_NETWORK_TESTNET_V2 = 325000
    WABA_CHAIN_TESTNET = 327126
    NAL_MAINNET = 328527
    TTCOIN_SMART_CHAIN_MAINNET = 330844
    BLOOM_GENESIS_MAINNET = 333313
    AVES_TESTNET = 333331
    NATIV3_TESTNET = 333333
    OONE_CHAIN_TESTNET = 333666
    OONE_CHAIN_DEVNET = 333777
    POLIS_TESTNET = 333888
    POLIS_MAINNET = 333999
    UPCHAIN_TESTNET = 336655
    UPCHAIN_MAINNET = 336666
    BITFINITY_NETWORK_MAINNET = 355110
    BITFINITY_NETWORK_TESTNET = 355113
    LAVITA_MAINNET = 360890
    DIGIT_SOUL_SMART_CHAIN_2 = 363636
    HAPCHAIN_TESTNET = 373737
    METAL_C_CHAIN = 381931
    METAL_TAHOE_C_CHAIN = 381932
    CHEESECHAIN = 383353
    TIPBOXCOIN_MAINNET = 404040
    AIE_TESTNET = 413413
    KEKCHAIN = 420420
    KEKCHAIN_KEKTEST = 420666
    ALTERIUM_L2_TESTNET = 420692
    ARBITRUM_RINKEBY = 421611
    ARBITRUM_GOERLI = 421613
    ARBITRUM_SEPOLIA = 421614
    FASTEX_CHAIN_TESTNET = 424242
    MARKR_GO = 431140
    DEXALOT_SUBNET_TESTNET = 432201
    DEXALOT_SUBNET = 432204
    SYNDR_L3_SEPOLIA = 444444
    WEELINK_TESTNET = 444900
    PATEX_SEPOLIA_TESTNET = 471100
    ULTRA_PRO_MAINNET = 473861
    OPENCHAIN_MAINNET = 474142
    WORLD_CHAIN_SEPOLIA_TESTNET_DEPRECATED = 484752
    GOBBL_TESTNET = 486487
    AUTONOMYS_TESTNET_NOVA_DOMAIN = 490000
    PLAYDAPP_NETWORK = 504441
    CMP_TESTNET = 512512
    DISCHAIN = 513100
    DOCOIN_COMMUNITY_CHAIN = 526916
    SCROLL_SEPOLIA_TESTNET = 534351
    SCROLL = 534352
    SCROLL_ALPHA_TESTNET = 534353
    SCROLL_PRE_ALPHA_TESTNET = 534354
    SHINARIUM_BETA = 534849
    BEANECO_SMARTCHAIN = 535037
    OVERPROTOCOL_TESTNET = 541764
    ZERO_NETWORK = 543210
    ONE_WORLD_CHAIN_TESTNET = 552981
    PENTAGON_TESTNET = 555555
    ECLIPSE_TESTNET = 555666
    DUSTBOY_IOT = 555888
    DJT_TESTNET = 621847
    HYPRA_MAINNET = 622277
    ATLAS = 622463
    POLTER_TESTNET = 631571
    BEAR_NETWORK_CHAIN_MAINNET = 641230
    ALL_MAINNET = 651940
    EDU_CHAIN_TESTNET = 656476
    XAI_MAINNET = 660279
    VISION_VPIONEER_TEST_CHAIN = 666666
    HELA_OFFICIAL_RUNTIME_TESTNET = 666888
    WON_NETWORK = 686868
    GALADRIEL_DEVNET = 696969
    TILTYARD_MAINNET_SUBNET = 710420
    SEI_DEVNET = 713715
    ERAM_MAINNET = 721529
    TIXCHAIN_TESTNET = 723107
    HEMI_SEPOLIA = 743111
    BEAR_NETWORK_CHAIN_TESTNET = 751230
    TERNOA_TESTNET = 752024
    PAYSCAN_CHAIN = 756689
    MIEXS_SMARTCHAIN = 761412
    INK_SEPOLIA = 763373
    LAMINA1_TESTNET = 764984
    LAMINA1_IDENTITY_TESTNET = 767368
    MODULARIUM = 776877
    ZEBRO_SMART_CHAIN = 786786
    OCTASPACE = 800001
    BIZ_SMART_CHAIN_TESTNET = 808080
    BOB_SEPOLIA = 808813
    ZKLINK_NOVA_MAINNET = 810180
    ZKLINK_NOVA_SEPOLIA_TESTNET = 810181
    ZKLINK_NOVA_GOERLI_TESTNET = 810182
    SG_VERSE_MAINNET = 812397
    TSC_TESTNET = 820522
    CURVE_MAINNET = 827431
    PRM_TESTNET = 839320
    EXSAT_TESTNET = 839999
    RUNEVM_TESTNET = 840000
    _4GOODNETWORK = 846000
    DODAO = 855456
    BLOCX_MAINNET = 879151
    REXX_MAINNET = 888882
    VISION_MAINNET = 888888
    UNITE_TESTNET = 888991
    POSICHAIN_MAINNET_SHARD_0 = 900000
    POSICHAIN_TESTNET_SHARD_0 = 910000
    ODYSSEY_TESTNET = 911867
    ASTRIA_EVM_DUSKNET = 912559
    OWSHEN_MAINNET = 918273
    POSICHAIN_DEVNET_SHARD_0 = 920000
    POSICHAIN_DEVNET_SHARD_1 = 920001
    FNCY_TESTNET = 923018
    JONO12_SUBNET = 955081
    ELUVIO_CONTENT_FABRIC = 955305
    TREASURE_RUBY = 978657
    TREASURE_TOPAZ = 978658
    FORMA = 984122
    FORMA_SKETCHPAD = 984123
    ECROX_CHAIN_MAINNET = 988207
    SUPERNET_TESTNET = 998899
    AMCHAIN = 999999
    NETMIND_CHAIN_TESTNET = 1100789
    TILTYARD_SUBNET = 1127469
    _1MONEY_NETWORK_TESTNET = 1212101
    SHARECLE_MAINNET = 1234567
    ZKATANA = 1261120
    ETHO_PROTOCOL = 1313114
    XEROM = 1313500
    KINTSUGI = 1337702
    KILN = 1337802
    ZHEJIANG = 1337803
    AUTOMATA_TESTNET = 1398243
    AUTOMATA_ORBIT_TESTNET = 1398244
    WATERFALL_9_TEST_NETWORK = 1501869
    PLAYFI_ALBIREO_TESTNET = 1612127
    XTERIO_TESTNET = 1637450
    TURKEY_DEMO_DEV = 1731313
    XPHERE_TESTNET = 1998991
    DEBANK_TESTNET = 2021398
    PLIAN_MAINNET_MAIN = 2099156
    PLATON_DEV_TESTNET_DEPRECATED = 2203181
    PLATON_DEV_TESTNET2 = 2206132
    COINWEB_BNB_SHARD = 2222222
    DPU_CHAIN = 2611555
    XTERIO_CHAIN_ETH = 2702128
    SAHARAAI_NETWORK = 3132023
    FILECOIN_BUTTERFLY_TESTNET = 3141592
    FUNKI_SEPOLIA_TESTNET = 3397901
    MANTA_PACIFIC_TESTNET = 3441005
    MANTA_PACIFIC_SEPOLIA_TESTNET = 3441006
    ALTLAYER_ZERO_GAS_NETWORK = 4000003
    WORLDS_CALDERA = 4281033
    ALTAR_TESTNET = 4444444
    ZERO_TESTNET_SEPOLIA = 4457845
    NUMBLOCK_CHAIN = 5112023
    MXC_WANNSEE_ZKEVM_TESTNET = 5167003
    MOONCHAIN_GENEVA_TESTNET = 5167004
    ELECTRONEUM_TESTNET = 5201420
    REACTIVE_KOPLI = 5318008
    POINTPAY_TESTNET = 5511555
    IMVERSED_MAINNET = 5555555
    IMVERSED_TESTNET = 5555558
    ASTAR_ZKYOTO = 6038361
    SAFE_ANWANG_MAINNET = 6666665
    SAFE_ANWANG_TESTNET = 6666666
    COTI_TESTNET = 7082400
    SAAKURU_MAINNET = 7225878
    OPENVESSEL = 7355310
    QL1_TESTNET = 7668378
    MUSICOIN = 7762959
    ZORA = 7777777
    PLIAN_MAINNET_SUBCHAIN_1 = 8007736
    FHENIX_HELIUM = 8008135
    HOKUM = 8080808
    WATERFALL_8_TEST_NETWORK = 8601152
    HAPCHAIN = 8794598
    QUARIX_TESTNET = 8888881
    QUARIX = 8888888
    XCAP = 9322252
    MILVINE = 9322253
    FLUENCE = 9999999
    SPOTLIGHT = 10058111
    SPOTLIGHT_SEPOLIA_TESTNET = 10058112
    PLIAN_TESTNET_SUBCHAIN_1 = 10067275
    SOVERUN_MAINNET = 10101010
    ALIENX_MAINNET = 10241024
    ALIENX_HAL_TESTNET = 10241025
    BLESSNET_SEPOLIA = 11145513
    SEPOLIA = 11155111
    OP_SEPOLIA_TESTNET = 11155420
    R0AR_TESTNET = 11166111
    LUMMIO_NETWORK = 12020498
    MEMENTO_TESTNET = 12052024
    NEOX_TESTNET_T3 = 12227331
    NEO_X_TESTNET_T4 = 12227332
    COTI_DEVNET = 13068200
    PEPCHAIN_CHURCHILL = 13371337
    ANDUSCHAIN_MAINNET = 14288640
    PLIAN_TESTNET_MAIN = 16658437
    LAMBDA_CHAIN_TESTNET = 17000920
    MANDE_NETWORK_MAINNET = 18071918
    IOLITE = 18289463
    DEEPBRAINCHAIN_TESTNET = 19850818
    DEEPBRAINCHAIN_MAINNET = 19880818
    STABILITY_TESTNET = 20180427
    SMARTMESH_MAINNET = 20180430
    QUARKBLOCKCHAIN = 20181205
    PEGO_NETWORK = 20201022
    VCITY_TESTNET = 20230825
    DEBANK_SEPOLIA_TESTNET = 20240324
    DBK_CHAIN = 20240603
    SWAN_PROXIMA_TESTNET = 20241133
    HOKUM_TESTNET = 20482050
    CORN_MAIZENET = 21000000
    CORN_TESTNET = 21000001
    EXCELON_MAINNET = 22052002
    XMTP = 24132016
    _6DEGREE_OF_OUTREACH_TESTNET = 24772477
    EXCOINCIAL_CHAIN_VOLTA_TESTNET = 27082017
    EXCOINCIAL_CHAIN_MAINNET = 27082022
    ANCIENT8_TESTNET = 28122024
    AUXILIUM_NETWORK_MAINNET = 28945486
    FLACHAIN_MAINNET = 29032022
    FILECOIN_LOCAL_TESTNET = 31415926
    TOLIMAN_SUAVE_TESTNET = 33626250
    XONE_TESTNET = 33772211
    CITRONUS_CITRO = 34949059
    JOYS_DIGITAL_MAINNET = 35855456
    SKALE_NEBULA_HUB_TESTNET = 37084624
    KINGDOM_CHAIN = 39916801
    MAISTESTSUBNET = 43214913
    STAVANGER_PUBLIC_TESTNET = 50591822
    DEVIANT_TOKEN_BLOCKCHAIN = 52027071
    DEVIANT_TOKEN_BLOCKCHAIN_TESTNET = 52027080
    FLUENCE_TESTNET = 52164803
    AQUACHAIN = 61717561
    AUTONITY_BAKERLOO_THAMES_TESTNET = 65010000
    AUTONITY_BAKERLOO_BARADA_TESTNET = 65010001
    AUTONITY_BAKERLOO_SUMIDA_TESTNET = 65010002
    AUTONITY_BAKERLOO_YAMUNA_TESTNET = 65010003
    AUTONITY_PICCADILLY_THAMES_TESTNET = 65100000
    AUTONITY_PICCADILLY_BARADA_TESTNET = 65100001
    AUTONITY_PICCADILLY_SUMIDA_TESTNET = 65100002
    AUTONITY_PICCADILLY_YAMUNA_TESTNET = 65100003
    FRAME_TESTNET = 68840142
    _0XHASH_TESTNET = 77787778
    SX_TORONTO_ROLLUP = 79479957
    BACKSTOP_TESTNET = 88558801
    T_E_A_M_BLOCKCHAIN = 88888888
    REYA_CRONOS = 89346162
    POLYGON_BLACKBERRY = 94204209
    CHADCHAIN = 97912060
    JOYS_DIGITAL_TESTNET = 99415706
    ETHOS = 100000000
    ORAICHAIN_MAINNET = 108160679
    CYBER_TESTNET = 111557560
    OP_CELESTIA_RASPBERRY = 123420111
    PLUME_TESTNET = 161221135
    BLAST_SEPOLIA_TESTNET = 168587773
    GATHER_MAINNET_NETWORK = 192837465
    KANAZAWA = 222000222
    XMTP_SEPOLIA = 241320161
    NEON_EVM_DEVNET = 245022926
    NEON_EVM_DEVNET_ROLLUP = 245022929
    NEON_EVM_MAINNET = 245022934
    NEON_EVM_TESTNET = 245022940
    FLAME = 253368190
    RAZOR_SKALE_CHAIN = 278611351
    ONELEDGER_MAINNET = 311752642
    NAL_SEPOLIA_TESTNET = 328527624
    MELD = 333000333
    DEPRECATED_SKALE_CALYPSO_HUB_TESTNET = 344106930
    GATHER_TESTNET_NETWORK = 356256156
    WESTEND_ASSET_HUB = 420420421
    DEPRECATED_SKALE_EUROPA_HUB_TESTNET = 476158412
    SKOPJE_TESTNET = 476462898
    GATHER_DEVNET_NETWORK = 486217935
    DEPRECATED_SKALE_NEBULA_HUB_TESTNET = 503129905
    SOPHON_TESTNET = 531050104
    DEGEN_CHAIN = 666666666
    TRON_MAINNET = 728126428
    ANCIENT8 = 888888888
    PTCESCAN_TESTNET = 889910245
    PTCESCAN_MAINNET = 889910246
    SKALE_CALYPSO_HUB_TESTNET = 974399131
    LUMIA_MAINNET = 994873017
    ZORA_SEPOLIA_TESTNET = 999999999
    SKALE_TITAN_HUB_TESTNET = 1020352220
    IPOS_NETWORK = 1122334455
    CYBERDECKNET = 1146703430
    HUMAN_PROTOCOL = 1273227453
    AURORA_MAINNET = 1313161554
    AURORA_TESTNET = 1313161555
    AURORA_BETANET = 1313161556
    POWERGOLD = 1313161560
    SKALE_TITAN_HUB = 1350216234
    CHAOS_SKALE_TESTNET = 1351057110
    RARI_CHAIN_MAINNET = 1380012617
    RAPTORCHAIN = 1380996178
    SKALE_EUROPA_HUB_TESTNET = 1444673419
    SKALE_NEBULA_HUB = 1482601649
    GPT_MAINNET = 1511670449
    DEPRECATED_SKALE_TITAN_HUB_TESTNET = 1517929550
    SKALE_CALYPSO_HUB = 1564830818
    HAUST_TESTNET = 1570754601
    HARMONY_MAINNET_SHARD_0 = 1666600000
    HARMONY_MAINNET_SHARD_1 = 1666600001
    HARMONY_MAINNET_SHARD_2 = 1666600002
    HARMONY_MAINNET_SHARD_3 = 1666600003
    HARMONY_TESTNET_SHARD_0 = 1666700000
    HARMONY_TESTNET_SHARD_1 = 1666700001
    HARMONY_DEVNET_SHARD_0 = 1666900000
    HARMONY_DEVNET_SHARD_1 = 1666900001
    SILICON_ZKEVM_SEPOLIA_TESTNET = 1722641160
    GEMUCHAIN_TESTNET = 1903648807
    RARI_CHAIN_TESTNET = 1918988905
    LUMIA_TESTNET = 1952959480
    DATAHOPPER = 2021121117
    SKALE_EUROPA_HUB = 2046399126
    ACCUMULATE_KERMIT = 2478899481
    ANCIENT8_TESTNET_DEPRECATED = 2863311531
    PIRL = 3125659152
    ONELEDGER_TESTNET_FRANKENSTEIN = 4216137055
    MEKONG = 7078815900
    PALM_TESTNET = 11297108099
    PALM = 11297108109
    GITSWARM_TEST_NETWORK = 28872323069
    XAI_TESTNET_V2 = 37714555429
    DERIW_DEVNET = 44474237230
    ARBITRUM_BLUEBERRY = 88153591557
    ALPHABET_MAINNET = 111222333444
    THANOS_SEPOLIA = 111551119090
    FLUENCE_STAGE = 123420000220
    PIN = 123420000558
    SIVO_DEFI_TESTNET = 123420000586
    VOLMEX = 123420000588
    NTITY_MAINNET = 197710212030
    HARADEV_TESTNET = 197710212031
    GM_NETWORK_TESTNET = 202402181627
    ZENIQ = 383414847825
    PDC_MAINNET = 666301171999
    MOLEREUM_NETWORK = 6022140761023
    FLAME_TESTNET = 16604737732183
    KAKAROT_STARKNET_SEPOLIA = 920637907288165
    DCHAIN_TESTNET = 2713017997578000
    DCHAIN = 2716446429837000

    @classmethod
    def _missing_(cls, value):
        return cls.UNKNOWN
